<?php
/**
 * Theme backward compatibility
 *
 * @package AmberyTheme
 * @version 1.0.0
 */

/**
 * Prevent switching to theme on WordPress versions prior to 4.5.
 * Switches to the default theme.
 */
function ambery_switch_theme() {
	switch_theme( WP_DEFAULT_THEME );
	unset( $_GET['activated'] );
	add_action( 'admin_notices', 'ambery_upgrade_notice' );
}
add_action( 'after_switch_theme', 'ambery_switch_theme' );

/**
 * Message after unsuccessful theme switch attempt.
 */
function ambery_upgrade_notice() {
	echo '<div class="error"><p>';
	printf(
		/* translators: %s: WordPress Version. */
		esc_html__( 'This theme requires WordPress 5.3 or newer. You are running version %s. Please upgrade and try again.', 'ambery' ),
		esc_html( $GLOBALS['wp_version'] )
	);
	echo '</p></div>';
}

/**
 * Prevents Customizer loading on WordPress versions prior to 5.3.
 */
function ambery_prevent_customizer_loading() {
	wp_die(
		sprintf(
			/* translators: %s: WordPress Version. */
			esc_html__( 'This theme requires WordPress 5.3 or newer. You are running version %s. Please upgrade and try again.', 'ambery' ),
			esc_html( $GLOBALS['wp_version'] )
		),
		'',
		array(
			'back_link' => true,
		)
	);
}
add_action( 'load-customize.php', 'ambery_prevent_customizer_loading' );

/**
 * Prevents Theme Preview loading on WordPress versions prior to 5.3.
 */
function ambery_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die(
			sprintf(
				/* translators: %s: WordPress Version. */
				esc_html__( 'This theme requires WordPress 5.3 or newer. You are running version %s. Please upgrade and try again.', 'ambery' ),
				esc_html( $GLOBALS['wp_version'] )
			)
		);
	}
}
add_action( 'template_redirect', 'ambery_preview' );

/**
 * Body open hook.
 */
if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        do_action( 'wp_body_open' );
    }
}