<?php
/**
 * Ambery Customizer
 *
 * @package AmberyTheme
 * @version 1.0.0
 */
 
//Set config scope
ambery_Kirki::add_config( 'ambery_config', array(
	'option_type'	 => 'theme_mod',
	'capability'	 => 'edit_theme_options',
) );

// Get Panels
require_once( get_template_directory() .'/includes/customizer/panels/panels.php' );

// Get Sections
require_once( get_template_directory() .'/includes/customizer/sections/general-sections.php' );
require_once( get_template_directory() .'/includes/customizer/sections/typography-sections.php' );
require_once( get_template_directory() .'/includes/customizer/sections/header-sections.php' );
require_once( get_template_directory() .'/includes/customizer/sections/footer-sections.php' );
require_once( get_template_directory() .'/includes/customizer/sections/blog-sections.php' );
require_once( get_template_directory() .'/includes/customizer/sections/widget-sections.php' );
require_once( get_template_directory() .'/includes/customizer/sections/cpt-sections.php' );
require_once( get_template_directory() .'/includes/customizer/sections/misc-sections.php' );
require_once( get_template_directory() .'/includes/customizer/sections/help-sections.php' );

// Get Fields
require_once( get_template_directory() .'/includes/customizer/fields/general-fields.php' );
require_once( get_template_directory() .'/includes/customizer/fields/typography-fields.php' );
require_once( get_template_directory() .'/includes/customizer/fields/header-fields.php' );
require_once( get_template_directory() .'/includes/customizer/fields/footer-fields.php' );
require_once( get_template_directory() .'/includes/customizer/fields/blog-fields.php' );
require_once( get_template_directory() .'/includes/customizer/fields/widget-fields.php' );
require_once( get_template_directory() .'/includes/customizer/fields/cpt-fields.php' );
require_once( get_template_directory() .'/includes/customizer/fields/misc-fields.php' );
require_once( get_template_directory() .'/includes/customizer/fields/help-fields.php' );

/**
 * Customizer Mods
 */
function ambery_customizer_register( $wp_customize ) {
	
	// Remove core sections
	$wp_customize->remove_section( 'themes' );
	
	// Remove core controls
	$wp_customize->remove_control( 'header_textcolor' );

	// title_tagline section priority
	$wp_customize->add_section( 'title_tagline' , array(
		'title'		=> esc_html__( 'Site Identity', 'ambery' ),
		'priority'	=> 1,
	));
	
	// Logo type select field
	$wp_customize->add_setting( 'ambery_logo_type', array(
  		'default' => 'ambery_text_logo',
	));

	$wp_customize->add_control( 'ambery_logo_type', array(
		'type' 		=> 'select',
		'section' 	=> 'title_tagline',
		'label'		=> esc_html__( 'Select Logo Type', 'ambery' ),
		'settings'	=> 'ambery_logo_type',
		'priority'	=> 1,
		'choices'	=> array(
			'ambery_img_logo' => esc_html__( 'Image Logo', 'ambery' ),
			'ambery_text_logo' => esc_html__( 'Text Logo', 'ambery' ),
			'ambery_site_title_logo' => esc_html__( 'Site Title', 'ambery' ),
		),
	) );
	
	// Logo Width
	$wp_customize->add_setting( 'ambery_logo_width', array(
		'default'      		=> '',
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'ambery_logo_width_control',
            array(
                'label'      	=> esc_html__( 'Logo Width', 'ambery' ),
				'description'	=> esc_html__( 'Logo will resize as per width.', 'ambery' ),
                'section'   	=> 'title_tagline',
                'settings'   	=> 'ambery_logo_width',
				'default'      	=> '',
                'priority'   	=> 8
            )
        )
    );
	
	// Logo Height
	$wp_customize->add_setting( 'ambery_logo_height', array(
		'default'      		=> '',
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'ambery_logo_height_control',
            array(
                'label'      	=> esc_html__( 'Logo Height', 'ambery' ),
				'description'	=> esc_html__( 'Logo will resize as per width. Height is just to serve for height attribute criteria.', 'ambery' ),
                'section'   	=> 'title_tagline',
                'settings'   	=> 'ambery_logo_height',
				'default'      	=> '',
                'priority'   	=> 8
            )
        )
    );
	
	// Alt logo
	$wp_customize->add_setting('ambery_alt_img_logo', array(
		'default'      		=> '',
		) 
	);
	
	$wp_customize->add_control( 
		new WP_Customize_Image_Control( 
			$wp_customize, 
			'ambery_alt_img_logo_control', 
			array(
        		'label' 		=> esc_html__('Alt Logo', 'ambery'),
				'description' 	=> esc_html__('Logo and Alt Logo will work for either for on-load header or on-scroll header as per header variation. Refresh window if not visible on customizer edit screen.', 'ambery'),
        		'section' 		=> 'title_tagline',
        		'settings'		=> 'ambery_alt_img_logo',
				'default'      	=> '',
				'priority' 	 	=> 8
    		)
		)
	);
	
	// Alt Logo Width
	$wp_customize->add_setting( 'ambery_alt_logo_width', array(
		'default'      		=> '',
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'ambery_alt_logo_width_control',
            array(
                'label'      	=> esc_html__( 'Alt Logo Width', 'ambery' ),
				'description'	=> esc_html__( 'Logo will resize as per width.', 'ambery' ),
                'section'   	=> 'title_tagline',
                'settings'   	=> 'ambery_alt_logo_width',
				'default'      	=> '',
                'priority'   	=> 8
            )
        )
    );
	
	// Alt Logo height
	$wp_customize->add_setting( 'ambery_alt_logo_height', array(
		'default'      		=> '',
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'ambery_alt_logo_height_control',
            array(
                'label'      	=> esc_html__( 'Alt Logo Height', 'ambery' ),
				'description'	=> esc_html__( 'Logo will resize as per width. Height is just to serve for height attribute criteria.', 'ambery' ),
                'section'   	=> 'title_tagline',
                'settings'   	=> 'ambery_alt_logo_height',
				'default'      	=> '',
                'priority'   	=> 8
            )
        )
    );
	
	// Responsive 
	$wp_customize->add_setting( 'ambery_resp_logo_type', array(
  		'default' 			=> 'ambery_resp_main_logo',
	));

	$wp_customize->add_control( 'ambery_resp_logo_type', array(
		'type' 			=> 'select',
		'section' 		=> 'title_tagline',
		'label'			=> esc_html__( 'Image Logo - Responsive Header', 'ambery' ),
		'description'	=> esc_html__( 'Choose any one of the Logo or Alt Logo assigned above', 'ambery' ),
		'settings'		=> 'ambery_resp_logo_type',
		'priority'		=> 8,
		'choices'		=> array(
			'ambery_resp_main_logo'	=> esc_html__( 'Logo', 'ambery' ),
			'ambery_resp_alt_logo' 	=> esc_html__( 'Alt Logo', 'ambery' ),
		),
	) );
	
	// Text Logo
	$wp_customize->add_setting( 'ambery_text_logo_text', array(
		'default'      		=> esc_html__( 'Logo', 'ambery' ),
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'ambery_text_logo_control',
            array(
                'label'      	=> esc_html__( 'Text Logo', 'ambery' ),
				'description'	=> esc_html__( 'Use this if need logo text other than Site Title. Typography can be found in - Typography and Styles section.', 'ambery' ),
                'section'   	=> 'title_tagline',
                'settings'   	=> 'ambery_text_logo_text',
				'default'      	=> esc_html__( 'Logo', 'ambery' ),
                'priority'   	=> 8
            )
        )
    );
	
	// background_image section
	$wp_customize->add_section( 'background_image' , array(
		'title'		=> esc_html__('Body background Image','ambery'),
		'priority'	=> 2,
	));
	// background_color section
	$wp_customize->add_section( 'colors' , array(
		'title'		=> esc_html__('Body background Color','ambery'),
		'priority'	=> 3,
	));

}
add_action( 'customize_register', 'ambery_customizer_register', 20 );
// customize_register

/**
 * Customizer css
 */
function ambery_panels_scripts() {
	wp_enqueue_style( 'customizer-style', get_template_directory_uri() . '/includes/customizer/customizer.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'ambery_panels_scripts' );