<?php
/**
 * Custom Excerpt
 */
 
/**
 * Get the excerpt
 */
if ( ! function_exists( 'ambery_excerpt' ) ) {
	function ambery_excerpt( $args ) {
		echo ambery_get_the_excerpt( $args );
	}
} // ambery_excerpt

/**
 * Generate the custom excerpt
 */
if ( ! function_exists( 'ambery_get_the_excerpt' ) ) {
	function ambery_get_the_excerpt( $args = array() ) {
		$defaults = array(
			'output'          => '',
			'length'          => '40',
			'custom_excerpts' => true,
		);
		$args = wp_parse_args( $args, $defaults );
		extract( $args );
	
		// If length is empty or zero return
		if ( empty( $length ) || '0' == $length ) {
			return;
		}
	
		// Get post and post data
		$post = get_post();
		$post_content = $post->post_content;
		$post_excerpt = $custom_excerpts ? $post->post_excerpt : '';

		// If password protected post
		if ( $post->post_password ) {
			$output = '<p class="dtr-protected-msg">'. esc_html__( 'This is a password protected post.', 'ambery' ) .'</p>';
			return $output;
		}

		// default excerpt if provided
		if ( $post_excerpt ) :
			$output = $post_excerpt;
		// build custom excerpt
		else :
			// excerpt - complete post
			if ( '1' == $length ) {
				return apply_filters( 'the_content', $post_content );
				
			// excerpt - more tag
			} elseif ( '999' == $length ) {
				return apply_filters( 'the_content', get_the_content( '', '&hellip;' ) );
		
			// excerpt - custom length 
			} else { 	
				$content = wp_trim_words( $post_content, $length );
				$output = $content;
			}
		endif;
		// return excerpt	
		return $output;
	}
}
	
/**
 * Custom excerpt length for archives
 */
if ( ! function_exists( 'ambery_archive_excerpt_length' ) ) {
	function ambery_archive_excerpt_length() {
		$length = get_theme_mod( 'ambery_get_archive_excerpt_length', '40' );
		if ( $length ) {
			return intval( $length );
		} else {
			return 40; 	
		}
	}
} // ambery_archive_excerpt_length

/**
 * Get read more link
 */
if ( ! function_exists( 'ambery_read_more' ) ) {
	function ambery_read_more() {
		echo ambery_get_read_more();
	}
} // ambery_read_more

/**
 * Generate read more link
 */
if ( ! function_exists( 'ambery_get_read_more' ) ) {
	function ambery_get_read_more() {
	
		$output = $readmore = $class = '';
		$post = get_post();
		$post_id = $post->ID;

		$readmore = get_theme_mod( 'ambery_read_more_text', esc_html__( 'Continue Reading', 'ambery') );
		$output .= '<p><a href="'. get_permalink( $post_id ) .'" class="dtr-read-more" title="'. esc_attr( $readmore ) .'" rel="bookmark">'. esc_attr( $readmore ) .'</a></p>';
		// return read more link	
		return $output;
	}
}