<?php
/**
 * Paginations
 *
 * @package AmberyTheme
 * @version 1.0.0
 */
// atributes to navigation links
if ( ! function_exists( 'ambery_next_posts_link_attributes' ) ) {
	function ambery_next_posts_link_attributes() {
		return 'aria-label="' . esc_attr__('Next Post','ambery') . '"';
	}
}
add_filter('next_posts_link_attributes', 'ambery_next_posts_link_attributes');

if ( ! function_exists( 'ambery_prev_posts_link_attributes' ) ) {
	function ambery_prev_posts_link_attributes() {
		return 'aria-label="' . esc_attr__('Previous Post','ambery') . '"';
	}
}
add_filter('previous_posts_link_attributes', 'ambery_prev_posts_link_attributes');

/**
 * Navigation : title next/prev for a single post
 */
if ( ! function_exists( 'ambery_title_post_nav' ) ) :
	function ambery_title_post_nav() { 
	?>
	<nav class="dtr-single-post-nav dtr-title-nav">
		<?php $prev_post = get_previous_post(); ?>
		<div class="dtr-single-nav-prev">
        <?php if( $prev_post ) { ?>
			<?php previous_post_link('%link',"<h6 class='dtr-single-nav-prev-heading'>%title</h6>"); ?>
		<?php } ?>
		</div>
		<?php $next_post = get_next_post(); ?>
		<div class="dtr-single-nav-next">
        <?php if( $next_post ) { ?>
			<?php next_post_link('%link',"<h6 class='dtr-single-nav-next-heading'>%title</h6>"); ?>
        <?php } ?>
		</div>
	</nav>
	<?php
	}
endif; // ambery_title_post_nav

/**
 * Navigation : next/prev for a single post
 */
if ( ! function_exists( 'ambery_post_nav' ) ) :
	function ambery_post_nav() { 
	?>
	<nav class="dtr-single-post-nav">
		<?php $prev_post = get_previous_post(); 
		 $prev_nav_text	 = get_theme_mod('ambery_prev_nav_text', esc_html__('Previous Post','ambery')); ?>
		<div class="dtr-single-nav-prev">
        <?php if( $prev_post ) { ?>
			<?php previous_post_link('%link','<h6 class="dtr-single-nav-prev-heading">' . esc_html( $prev_nav_text ) . '</h6>'); ?>
		<?php } ?>
		</div>
		<?php $next_post = get_next_post(); 
		$next_nav_text	 = get_theme_mod('ambery_next_nav_text', esc_html__('Next Post','ambery')); ?>
		<div class="dtr-single-nav-next">
        <?php if( $next_post ) { ?>
        	<?php next_post_link('%link','<h6 class="dtr-single-nav-next-heading">' . esc_html( $next_nav_text ) . '</h6>'); ?>
        <?php } ?>
		</div>
	</nav>
	<?php
	}
endif; // ambery_post_nav

/**
 * Navigation : next/prev for a single portfolio post
 */
if ( ! function_exists( 'ambery_portfolio_nav' ) ) :
	function ambery_portfolio_nav() { 
	?>
	<nav class="dtr-single-post-nav">
		<?php $prev_post = get_previous_post(); 
		 $prev_nav_text	 = get_theme_mod('ambery_portfolio_prev_nav_text', esc_html__('Previous Project','ambery')); ?>
		<div class="dtr-single-nav-prev">
        <?php if( $prev_post ) { ?>
			<?php previous_post_link('%link','<h6 class="dtr-single-nav-prev-heading">' . esc_html( $prev_nav_text ) . '</h6>'); ?>
		<?php } ?>
		</div>
		<?php $next_post = get_next_post(); 
		$next_nav_text	 = get_theme_mod('ambery_portfolio_next_nav_text', esc_html__('Next Project','ambery')); ?>
		<div class="dtr-single-nav-next">
        <?php if( $next_post ) { ?>
        	<?php next_post_link('%link','<h6 class="dtr-single-nav-next-heading">' . esc_html( $next_nav_text ) . '</h6>'); ?>
        <?php } ?>
		</div>
	</nav>
	<?php
	}
endif; // ambery_post_nav

/**
 * Navigation : next/prev for archives
 */
if ( ! function_exists( 'ambery_archive_nav' ) ) :
function ambery_archive_nav() {
	global $wp_query;
	if ( $wp_query->max_num_pages < 2 )
		return;
	?>
<nav class="dtr-post-navigation dtr-archive-nav clearfix">
	<div class="dtr-post-nav clearfix">
		<div class="dtr-previous-link">
			<?php if ( get_next_posts_link() ) : ?>
			<?php next_posts_link( '<div class="dtr-previous-link-title"></div>' );  ?>
			<?php endif; ?>
		</div>
		<div class="dtr-next-link">
			<?php if ( get_previous_posts_link() ) : ?>
			<?php previous_posts_link( '<div class="dtr-next-link-title"></div>' ); ?>
			<?php endif; ?>
		</div>
	</div>
</nav>
<!-- .dtr-post-navigation -->
<?php
}
endif; // ambery_archive_nav

/**
 * Pagination : Numbered 
 */
if ( ! function_exists( 'ambery_numbered_pagination' ) ) :
    function ambery_numbered_pagination( $query = '' ) {

        if ( ! $query ) {
            global $wp_query;
            $query = $wp_query;
        }
		
		// vars
		$total  = $query->max_num_pages;
        $big    = 999999999; // unlikely integer

		// pagination
        if ( $total > 1 ) {
		
            // Get permalink structure
            if ( get_option( 'permalink_structure' ) ) {
                if ( is_page() ) {
                    $format = 'page/%#%/';
                } else {
                    $format = '/%#%/';
                }
            } else {
                $format = '&paged=%#%';
            }

            // Get current page
            if ( $current_page = get_query_var( 'paged' ) ) {
                $current_page = $current_page;
            } elseif ( $current_page = get_query_var( 'page' ) ) {
                $current_page = $current_page;
            } else {
                $current_page = 1;
            }

            // Midsize
            $mid_size = '2';
			
            // Pagination output
            $links = paginate_links( array(
                'base'          => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
                'format'        => $format,
                'total'         => $total,
				'current'       => max( 1, $current_page ),
                'mid_size'      => $mid_size,
                'prev_next'     => false,
                'next_text'     => false,
			    'type'          => 'array'
            ) );
			
			if ( $links ) :
	
	 if ( '' == get_previous_posts_link() ) {
		$page_number_style = 'dtr-page-numbers-left'; 
	 } elseif ( '' == get_next_posts_link() ) {
	 	$page_number_style = 'dtr-page-numbers-right'; 
	 } else { $page_number_style = ''; }
	 
    echo '<ul class="dtr-page-numbers clearfix ' . esc_attr( $page_number_style ) . '">';
    if ( get_previous_posts_link() ) :
        echo '<li class="dtr-previous-link-numbers">';
        echo get_previous_posts_link( '<div class="dtr-previous-link-title-numbers"></div>' );
        echo '</li>';
    endif;

    echo '<li class="dtr-simple-numbers">';
    echo join( '</li><li>', $links );
    echo '</li>';

    if ( get_next_posts_link() ) :
        echo '<li class="dtr-next-link-numbers">';
		echo get_next_posts_link( '<div class="dtr-next-link-title-numbers"></div>' );
        echo '</li>';
    endif;
    echo '</ul>';
endif;
        }
    }
endif; // ambery_numbered_pagination