<?php
/**
 * The Page header for archives
 *
 * @package AmberyTheme
 * @version 1.0.0
 */
// Page header hook
function ambery_page_header_hook() {
	do_action( 'ambery_page_header_hook' );
}
add_action( 'ambery_page_header_hook', 'ambery_default_page_header_hook' );

if( ! function_exists( 'ambery_default_page_header_hook' ) ) {
	function ambery_default_page_header_hook() {
		ambery_page_header();
	}
}
// Build Page Title
if ( ! function_exists('ambery_page_title') ) {
	function ambery_page_title( $page_title='' ) {
		
		if ( is_home() ) { 
			$page_title = get_theme_mod( 'ambery_blog_title', esc_html__('Blog','ambery') ); 
		}
		// Archives   
		elseif ( is_archive() ) {
			// category
			if ( is_category() ) {
				$page_title = sprintf( single_cat_title( '', false ) );
			// tag
			} elseif ( is_tag() ) {
        		$page_title = sprintf( single_tag_title( '', false ) );
			// Daily archive
			} elseif ( is_day() ) {
				$page_title = sprintf( get_the_date() );
			// Monthly archive
			} elseif ( is_month() ) {
				$page_title = sprintf( get_the_date( _x( 'F Y', 'monthly archives date format', 'ambery' ) ) );	
			// Yearly archive
			} elseif ( is_year() ) {
				$page_title = sprintf( get_the_date( _x( 'Y', 'yearly archives date format', 'ambery' ) ) );	
			//Author
			} elseif ( is_author() ) { 
         		$page_title = sprintf( get_the_author() );
			// Standard title
			} else {
				$page_title = single_term_title("", false);
				if ( $page_title == '' ) {
					$post_id = get_the_ID();
					$page_title = get_the_title( $post_id );
				}
			}
		// Search
		} elseif( is_search() ) {
			/* translators: %s: search query. */
			$page_title =  sprintf( esc_html__( ' Search Results : %s', 'ambery' ), get_search_query() );   
		// else
		} else {
			$post_id = get_the_ID();
			$page_title = get_the_title( $post_id );
		}
		return $page_title;
	} 
} 
// Page Header output
if ( ! function_exists( 'ambery_page_header' ) ) {
	function ambery_page_header() {
		global $post;
		$page_title	= ambery_page_title();
		
		if ( is_front_page() || is_page() || is_single() ) return;
		if ( 'hide' == get_theme_mod( 'ambery_archive_title_enable', 'show' )  ) return;
		$title_align = get_theme_mod( 'ambery_page_title_section_align', 'text-left' );

?>
<div class="dtr-page-title-main <?php echo esc_attr( $title_align ); ?>">
	<div class="dtr-page-title-wrapper">
		<div class="dtr-page-title-overlay"></div>
		<div class="container">
			<?php if ( 'show' == get_theme_mod( 'ambery_archive_heading_enable', 'show' ) ) { ?>
			<h1 class="dtr-blog-title dtr-page-title" <?php ambery_schema_markup( 'headline' ); ?>> <?php echo esc_html( $page_title ); ?> </h1>
			<?php } ?>
            <?php if ( function_exists('bcn_display_list') && 'show' == get_theme_mod( 'ambery_archive_breadcrumb_enable', 'show' ) ) { ?>
			<div class="dtr-breadcrumb-wrapper">
				<?php get_template_part( '/template-parts/header/breadcrumb' ); ?>
			</div>
			<?php } ?>
		</div>
	</div>
</div>
<?php	
    } 
}