<?php
/**
 * Include and setup custom metaboxes and fields.
 */
add_action( 'cmb2_admin_init', 'ambery_metaboxes' );
/**
 * Hook in and add a metabox
 */
function ambery_metaboxes() {
	
	// Prefix
	$prefix = '_ambery_';
	
	/**
	 * Testimonial Settings
	 */
	$ambery_testimonial_metabox = new_cmb2_box( array(
		'id'            => $prefix . 'testimonial-settings-metabox',
		'title'         => esc_html__( 'Testimonial Settings', 'ambery' ),
		'object_types'  => array( 'dtr_testimonial' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
	) );
	
	$ambery_testimonial_metabox->add_field( array(
		'desc'  =>  wp_kses( __( 'Title is used as ID to recognize respective testimonial. It will not be displayed frontend anywhere.<br>ID for Testimonial is <strong> Slug </strong> of Post === Title as viewed in permalink.', 'ambery'), array( 'br' => array(), 'strong' => array(), 'i' => array(), ) ),
		'id'   	=> $prefix . 'testimonial_shorthand',
		'type' 	=> 'title',
	) );
	
	$ambery_testimonial_metabox->add_field( array(
		'name' => esc_html__( 'Client Image', 'ambery' ),
		'desc' => esc_html__( 'Preferably of equal height and width', 'ambery' ),
		'id'   =>  $prefix . 'testimonial_client_image',
		'type' => 'file',
	) );
	
	$ambery_testimonial_metabox->add_field( array(
		'name'	=> esc_html__( 'Tagline', 'ambery' ),
		'id'   	=> $prefix . 'testimonial_tagline',
		'type'	=> 'text',
	) );
	
	$ambery_testimonial_metabox->add_field( array(
		'name'	=> esc_html__( 'Client Name', 'ambery' ),
		'id'   	=> $prefix . 'testimonial_client_name',
		'type'	=> 'text',
	) );
	
	$ambery_testimonial_metabox->add_field( array(
		'name'	=> esc_html__( 'Client Designation', 'ambery' ),
		'id'   	=> $prefix . 'testimonial_client_designation',
		'type'	=> 'text',
	) );

	// Page Layout
	$page_layout = array(
		'' 					=> esc_html__( 'Default', 'ambery' ),
		'dtr-fullwidth'		=> esc_html__( 'No Sidebar', 'ambery' ),
		'dtr-right-sidebar'	=> esc_html__( 'Right Sidebar', 'ambery' ),
		'dtr-left-sidebar' 	=> esc_html__( 'Left Sidebar', 'ambery' ),
	);
	
	// Page Header Background image styles
	$page_header_bg_image_style = array(
		'repeat'	=> esc_html__( 'Repeat', 'ambery' ),
		'stretched'	=> esc_html__( 'Stretched', 'ambery' ),
		'fixed'		=> esc_html__( 'Fixed', 'ambery' ),
	);

	/**
	 * Page Settings
	 */
	$ambery_page_metabox = new_cmb2_box( array(
		'id'            => $prefix . 'page-settings-metabox',
		'title'         => esc_html__( 'Page Settings', 'ambery' ),
		'object_types'  => array( 'page', 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
	) );

	$ambery_page_metabox->add_field( array(
		'id'   		=> $prefix . 'page_layout_meta',
		'name' 		=> esc_html__( 'Sidebar Position', 'ambery' ),
		'type' 		=> 'select',
		'options'	=> $page_layout,
	) );
	
	/**
	 * Page Header
	 */
	$ambery_page_header_metabox = new_cmb2_box( array(
		'id'            => $prefix . 'page-header-metabox',
		'title'         => esc_html__( 'Page Title Section Style', 'ambery' ),
		'object_types'	=> array( 'page', 'post', 'dtr_testimonial', 'dtr_portfolio' ), // Post type
		'context'    	=> 'normal',
		'priority'   	=> 'high',
	) );
	
	$ambery_page_header_metabox->add_field( array(
		'name' => esc_html__( 'Page Title Background Image - Upload or enter URL', 'ambery' ),
		'id'   =>  $prefix . 'page_header_bg_image',
		'type' => 'file',
	) );

	$ambery_page_header_metabox->add_field( array(
		'id'   		=> $prefix . 'page_header_bg_image_style',
		'name' 		=> esc_html__( 'Page Title Background Style', 'ambery' ),
		'type' 		=> 'select',
		'options'	=> $page_header_bg_image_style,
	) );

	/**
	 * Portfolio
	 */
	$ambery_portfolio_post_metabox = new_cmb2_box( array(
		'id'            => $prefix . 'portfolio-post-metabox',
		'title'         => esc_html__( 'Portfolio Grid Settings', 'ambery' ),
		'object_types'	=> array( 'dtr_portfolio' ), // Post type
		'context'    	=> 'side',
		'priority'   	=> 'high',
	) );
	$ambery_portfolio_post_metabox->add_field( array(
		'name'	=> esc_html__( 'If - Link to Heading in Portfolio Element - Needs to be External - Other than its linked single post', 'ambery' ),
		'desc'  => __('Give link here', 'ambery'),
		'id'   	=> $prefix . 'portfolio_external_link_url',
		'type'	=> 'text',
	) );
	
	$ambery_portfolio_post_metabox->add_field( array(
		'name'	=> esc_html__( 'Location', 'ambery' ),
		'desc'  => __('Will be displayed on - Portfolio Element - via Page Builder', 'ambery'),
		'id'   	=> $prefix . 'portfolio_item_location',
		'type'	=> 'text',
	) );
	
	$ambery_portfolio_post_metabox->add_field( array(
		'name'	=> esc_html__( 'Short Description', 'ambery' ),
		'desc'  => __('Will be displayed on - Portfolio Element - via Page Builder', 'ambery'),
		'id'   	=> $prefix . 'portfolio_item_desc',
		'type'	=> 'text',
	) );

} // ambery_metaboxes