<?php
/**
 * Contact Widget
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// class starts
if ( ! class_exists( 'AMBERY_Contact_Widget' ) ) {
	class AMBERY_Contact_Widget extends WP_Widget {
	
		/**
		 * Register widget
		 */
		public function __construct() {
			$widget_ops = array(
      			'classname' => 'ambery_contact_widget',
      			'description' => esc_html__( 'Display Contact Information', 'ambery' ),
    		);
    		parent::__construct( 'ambery_contact_widget', esc_html__( 'Custom: Contact', 'ambery' ), $widget_ops );
		}

		/**
	 	 * Output the content of the widget
		 */
		public function widget( $args, $instance ) {

			// vars
			$output 		= '';
			$email_title	= empty( $instance['email_title'] ) ? '' : $instance['email_title'];
			$email   		= empty( $instance['email'] ) ? '' : $instance['email'];
			$emailtxt  		= empty( $instance['emailtxt'] ) ? '' : $instance['emailtxt'];
			$website_title	= empty( $instance['website_title'] ) ? '' : $instance['website_title'];
			$website   		= empty( $instance['website'] ) ? '' : $instance['website'];
			$phone_title 	= empty( $instance['phone_title'] ) ? '' : $instance['phone_title'];
			$phone   		= empty( $instance['phone'] ) ? '' : $instance['phone'];
			$color_scheme   = isset( $instance['color_scheme'] ) ? $instance['color_scheme'] : 'dtr-widget-dark';
			// Before widget
			$output .= $args['before_widget'];

			// output starts
			$output .= '<div class="'. esc_attr( $color_scheme ) .'"><ul class="dtr-contact-widget clearfix">';
				// phone
				if ( $phone != '' ) {
					$output .= '<li class="dtr-contact-widget-phone">';
						$output .= '<span class="dtr-widget-icon"></span><p>' . esc_html( $phone_title ) . '<span class="dtr-widget-item-text">' . esc_html( $phone ) . '</span></p>'; 
					$output .= '</li>';
	
				}
				// email
				if ( $emailtxt != '' ) {
					$output .= '<li class="dtr-contact-widget-email">';
						$output .= '<span class="dtr-widget-icon"></span><p>' . esc_html( $email_title ) . '<span class="dtr-widget-item-text"><a class="dtr-contact-widget-link" href="mailto:' . esc_html( $email ) . '">' . esc_html( $emailtxt ) . '</a></span></p>'; 
					$output .= '</li>';
				}
				// website
				if ( $website != '' ) {
					$output .= '<li class="dtr-contact-widget-website">';
						$output .= '<span class="dtr-widget-icon"></span><p>' . esc_html( $website_title ) . '<span class="dtr-widget-item-text"><a class="dtr-contact-widget-link" href="' . esc_html( $website ) . '">' . esc_html( $website ) . '</a></span></p>'; 
					$output .= '</li>';
				}
			$output .= '</ul></div>';
	
			// output ends

			// After widget
			$output .= $args['after_widget'];

			// output echo
			echo $output;
		
		} 

		/**
		 *  Update the information in the WordPress database
		 */	
		 
		public function update( $new_instance, $old_instance ) {
			$instance                 	= $old_instance;
			$instance['phone_title']  	= isset( $new_instance['phone_title'] ) ? trim( strip_tags( $new_instance['phone_title'] ) ) : '';
			$instance['phone']  		= isset( $new_instance['phone'] ) ? trim( strip_tags( $new_instance['phone'] ) ) : '';
			$instance['website_title']	= isset( $new_instance['website_title'] ) ? trim( strip_tags( $new_instance['website_title'] ) ) : '';
			$instance['website']  		= isset( $new_instance['website'] ) ? trim( strip_tags( $new_instance['website'] ) ) : '';
			$instance['email_title']  	= isset( $new_instance['email_title'] ) ? trim( strip_tags( $new_instance['email_title'] ) ) : '';
			$instance['email']  		= isset( $new_instance['email'] ) ? trim( strip_tags( $new_instance['email'] ) ) : '';
			$instance['emailtxt']  		= isset( $new_instance['emailtxt'] ) ? trim( strip_tags( $new_instance['emailtxt'] ) ) : '';
			$instance['color_scheme']	= ! empty( $new_instance['color_scheme'] ) ? strip_tags( $new_instance['color_scheme'] ) : 'dtr-widget-dark';
			
			/**
			 * Register strings for WPML translation
			 */
			if ( function_exists ( 'icl_register_string' ) ){
				icl_register_string('Contact Widget', 'Phone Title', $instance['phone_title']);
				icl_register_string('Contact Widget', 'Phone', $instance['phone']);
				icl_register_string('Contact Widget', 'Website Title', $instance['website_title']);
				icl_register_string('Contact Widget', 'Email Title', $instance['email_title']);
				icl_register_string('Contact Widget', 'Email Text', $instance['emailtxt']);
			} // icl_register_string
				
			return $instance;
		} 

		/**
		 * Add form fields to the widget which will be displayed in the WordPress admin area.
		 */
		public function form( $instance ) {
			
			extract( wp_parse_args( $instance, array(
				'phone_title'	=> '',
				'phone'       	=> '',
				'website_title'	=> '',
				'website'       => '',
				'email_title'	=> '',
				'email'       	=> '',
				'emailtxt'      => '',
				'color_scheme'	=> 'dtr-widget-dark',
			) ) ); ?>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'phone_title' ) ); ?>">
		<?php esc_html_e( 'Phone Title', 'ambery' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'phone_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'phone_title' ) ); ?>" type="text" value="<?php echo esc_attr( $phone_title ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'phone' ) ); ?>">
		<?php esc_html_e( 'Phone', 'ambery' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'phone' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'phone' ) ); ?>" type="text" value="<?php echo esc_attr( $phone ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'email_title' ) ); ?>">
		<?php esc_html_e( 'Email Title', 'ambery' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'email_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'email_title' ) ); ?>" type="text" value="<?php echo esc_attr( $email_title ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'email' ) ); ?>">
		<?php esc_html_e( 'Email Link / URL', 'ambery' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'email' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'email' ) ); ?>" type="text" value="<?php echo esc_attr( $email ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'emailtxt' ) ); ?>">
		<?php esc_html_e( 'Email Link Text', 'ambery' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'emailtxt' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'emailtxt' ) ); ?>" type="text" value="<?php echo esc_attr( $emailtxt ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'website_title' ) ); ?>">
		<?php esc_html_e( 'Website Title', 'ambery' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'website_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'website_title' ) ); ?>" type="text" value="<?php echo esc_attr( $website_title ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'website' ) ); ?>">
		<?php esc_html_e( 'Website Link / URL', 'ambery' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'website' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'website' ) ); ?>" type="text" value="<?php echo esc_attr( $website ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'color_scheme' ) ); ?>">
		<?php esc_html_e( 'Color Scheme. Color Settings are in customizer > WP and Custom Widget Style > Contact Widget', 'ambery' ); ?>
		:</label>
	<br />
	<select name="<?php echo esc_attr( $this->get_field_name( 'color_scheme' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'color_scheme' ) ); ?>">
		<option value="dtr-widget-light" <?php selected( isset($instance['color_scheme']), 'dtr-widget-light' ); ?>>
		<?php esc_html_e( 'For Dark Backgrounds', 'ambery' ); ?>
		</option>
		<option value="dtr-widget-dark" <?php selected( isset($instance['color_scheme']), 'dtr-widget-dark' ); ?>>
		<?php esc_html_e( 'For Light Backgrounds', 'ambery' ); ?>
		</option>
	</select>
</p>
<?php
		} 
	// class ends
	}
}
register_widget( 'AMBERY_Contact_Widget' );