<?php
namespace AmberyAddons;

use AmberyAddons\Widgets\Ambery_Section_Intro;
use AmberyAddons\Widgets\Ambery_Animated_Heading;
use AmberyAddons\Widgets\Ambery_Blockquote;
use AmberyAddons\Widgets\Ambery_Button;
use AmberyAddons\Widgets\Ambery_Icon;
use AmberyAddons\Widgets\Ambery_Iconhead;
use AmberyAddons\Widgets\Ambery_Feature;
use AmberyAddons\Widgets\Ambery_Servicebox;
use AmberyAddons\Widgets\Ambery_Infobox;
use AmberyAddons\Widgets\Ambery_Team;
use AmberyAddons\Widgets\Ambery_Static_Infobox;
use AmberyAddons\Widgets\Ambery_Single_Image;
use AmberyAddons\Widgets\Ambery_Image_Lightbox;
use AmberyAddons\Widgets\Ambery_Testimonial_Thumbs_Carousel;
use AmberyAddons\Widgets\Ambery_Testimonial_Carousel;
use AmberyAddons\Widgets\Ambery_Marquee;
use AmberyAddons\Widgets\Ambery_Video_Lightbox;
use AmberyAddons\Widgets\Ambery_Portfolio;
use AmberyAddons\Widgets\Ambery_Recentposts_Carousel;
use AmberyAddons\Widgets\Ambery_Static_Recentposts;
use AmberyAddons\Widgets\Ambery_Single_Recentposts;
use AmberyAddons\Widgets\Ambery_Tabs;
use AmberyAddons\Widgets\Ambery_Accordion;
use AmberyAddons\Widgets\Ambery_Info;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Main Plugin Class
 * Register new elementor widget.
 * @since 1.0.0
 */
class Ambery_Elementor_Addons {
	
	/**
	 * Minimum Elementor Version
	 * @var string Minimum Elementor version required to run the plugin.
	 */
	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

	/**
	 * Constructor
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {
		$this->add_actions();
		$this->setup_hooks();
	}
	
	/**
	 * Add Actions
	 * @since 1.0.0
	 * @access private
	 */
	
	public function add_actions() {
		add_action( 'elementor/widgets/register', [ $this, 'on_widgets_registered' ] );
		add_action( 'elementor/init', array( $this, 'add_elementor_category' ) );
		
		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
			return;
		}
		
		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
			return;
		}
		
	}

	/**
	 * Admin notice
	 * Warning when the site doesn't have Elementor installed or activated.
	 * @access public
	 */
	public function admin_notice_missing_main_plugin() {
		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );
		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'ambery' ),
			'<strong>' . esc_html__( 'Ambery Elementor Addons', 'ambery' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'ambery' ) . '</strong>'
		);
		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}
	
	/**
	 * Admin notice
	 * Warning when the site doesn't have a minimum required Elementor version.
	 * @access public
	 */
	public function admin_notice_minimum_elementor_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'ambery' ),
			'<strong>' . esc_html__( 'Ambery Elementor Addons', 'ambery' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'ambery' ) . '</strong>',
			 self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Add setup_hooks
	 * @since 1.0.0
	 * @access private
	 */
	private function setup_hooks() {
		// Register Widget Styles
		add_action( 'elementor/editor/after_enqueue_styles', [ $this, 'widget_styles' ] );
		add_action( 'elementor/frontend/after_register_scripts',[ $this, 'register_frontend_scripts' ], 10 );
	}
	
	/**
	 * On Widgets Registered
	 * @since 1.0.0
	 * @access public
	 */
	public function on_widgets_registered() {
		$this->includes();
		$this->register_widget();
	}
	
	/**
	 * Add Category
	 * @since 1.0.0
	 * @access public
	 */
	 public function add_elementor_category() {
		\Elementor\Plugin::instance()->elements_manager->add_category(
			'dtr-element',
			array(
				'title' => __('Ambery Addons', 'ambery'),
				'icon' => 'fa fa-plug',
			),
			1);
      }

	/**
	 * Includes
	 * @since 1.0.0
	 * @access private
	 */
	private function includes() {
		
		require __DIR__ . '/inc/dtr-icons.php';
		require __DIR__ . '/widgets/dtr-section-intro.php';
		require __DIR__ . '/widgets/dtr-animated-heading.php';
		require __DIR__ . '/widgets/dtr-blockquote.php';
		require __DIR__ . '/widgets/dtr-button.php';
		require __DIR__ . '/widgets/dtr-icon.php';
		require __DIR__ . '/widgets/dtr-icon-heading.php';
		require __DIR__ . '/widgets/dtr-feature.php';
		require __DIR__ . '/widgets/dtr-servicebox.php';
		require __DIR__ . '/widgets/dtr-infobox.php';
		require __DIR__ . '/widgets/dtr-team.php';
		require __DIR__ . '/widgets/dtr-static-infobox.php';
		require __DIR__ . '/widgets/dtr-single-image.php';
		require __DIR__ . '/widgets/dtr-image-lightbox.php';
		require __DIR__ . '/widgets/dtr-testimonial-thumbs-carousel.php';
		require __DIR__ . '/widgets/dtr-testimonial-carousel.php';
		require __DIR__ . '/widgets/dtr-marquee.php';
		require __DIR__ . '/widgets/dtr-video-button.php';
		require __DIR__ . '/widgets/dtr-portfolio.php';
		require __DIR__ . '/widgets/dtr-recentposts-carousel.php';
		require __DIR__ . '/widgets/dtr-recentposts-static.php';
		require __DIR__ . '/widgets/dtr-recentposts-single.php';
		require __DIR__ . '/widgets/dtr-tabs.php';
		require __DIR__ . '/widgets/dtr-accordion.php';
		require __DIR__ . '/widgets/dtr-info.php';
	}

	/**
	 * Register Widget
	 * @since 1.0.0
	 * @access private
	 */
	private function register_widget() {
		
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Section_Intro() );	
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Animated_Heading() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Blockquote() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Button() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Icon() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Iconhead() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Feature() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Servicebox() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Infobox() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Team() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Static_Infobox() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Single_Image() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Image_Lightbox() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Testimonial_Thumbs_Carousel() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Testimonial_Carousel() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Marquee() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Video_Lightbox() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Portfolio() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Recentposts_Carousel() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Static_Recentposts() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Single_Recentposts() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Tabs() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Accordion() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Ambery_Info() );
	}
	
	/**
	 * enqueue styles
	 * @since 1.0.0
	 * @access public
	 */
	public function widget_styles() {
		
		wp_enqueue_style( 'dtr-custom-icons', AMBERY_ELEMENTOR_ADDONS_URL . 'fonts/iconfont.css' );
		
		// elementor pro css mod
		$elementor_pro_mod = '';
		$elementor_pro_mod = get_theme_mod( 'ambery_elementor_pro_mod', 'yes' );
		if ( $elementor_pro_mod == 'yes' && ! class_exists( 'ElementorPro\Plugin' ) ) {
			wp_enqueue_style( 'dtr-elementor-pro-mod', AMBERY_ELEMENTOR_ADDONS_URL . 'assets/css/elementor-pro-mod.css' );
		}
	}
	
	/**
	 * Load Frontend Scripts
	 *
	 */
	public function register_frontend_scripts() {
		wp_register_script( 'swiper', AMBERY_ELEMENTOR_ADDONS_URL . 'assets/js/swiper-bundle.min.js', array('jquery'), '5.0.3', true );
		wp_register_script( 'dtr-widgets', AMBERY_ELEMENTOR_ADDONS_URL . 'assets/js/dtr-widgets.js', array('jquery'), '1.0', true );
		wp_enqueue_style( 'font-awesome-5-all', ELEMENTOR_ASSETS_URL . 'lib/font-awesome/css/all.min.css' );
    } 
	
}
new Ambery_Elementor_Addons();