<?php
namespace AmberyAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\REPEATER;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Accordion Widget
 */
class Ambery_Accordion extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-accordion';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Accordion', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}
	
	public function get_keywords() {
		return [ 'tabs', 'accordion', 'toggle' ];
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	
	/**
	 * Register the scripts widget depends on.
	 */
	public function __construct( $data = [], $args = null ) {
		parent::__construct( $data, $args );
		wp_register_script( 'bootstrap.min', AMBERY_ELEMENTOR_ADDONS_URL . 'assets/js/bootstrap.min.js', [ 'elementor-frontend' ], '1.0.0', true );
		wp_register_script( 'dtr-widgets', AMBERY_ELEMENTOR_ADDONS_URL . 'assets/js/dtr-widgets.js', [ 'elementor-frontend' ], '1.0.0', true );
    }
   
	/**
	 * Retrieve the list of scripts the widget depends on.
	 * Used to set scripts dependencies required to run the widget.
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
        return [
			'bootstrap.min',
			'dtr-widgets'
        ];
    }
	
	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_timeline_content',
			[
				'label'	=> esc_html__( 'Accordion', 'ambery' ),
			]
		);
		
		$this->add_control(
			'accordion_icon_style',
			[
				'label' 	=> esc_html__( 'Icon Style', 'ambery' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'dtr-accordion-arrow',
				'label_block' 	=> true,
				'options'	=> [
					'dtr-accordion-circle'	=> esc_html__( 'Circle (Left Aligned)', 'ambery' ),
					'dtr-accordion-arrow'	=> esc_html__( 'Arrow (Right Aligned)', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'show_number',
			[
				'label' 	=> esc_html__( 'Show Prefix Number', 'ambery' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '',
				'label_block' 	=> true,
				'separator' => 'after',
				'options'	=> [
					'dtr-accordion-has-number'	=> esc_html__( 'Yes', 'ambery' ),
					''	=> esc_html__( 'No', 'ambery' ),
				],
				'condition' => [
					'accordion_icon_style'	=> [ 'dtr-accordion-arrow' ],
				],
			]
		);

		$repeater = new Repeater();
		
		// number
		$repeater->add_control(
			'accordion_number',
			[
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> '',
				'placeholder'	=> __( '01.', 'ambery' ),
				'label_block' 	=> true,
			]
		);
		
		// title
		$repeater->add_control(
			'accordion_title',
			[
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> __( 'Title', 'ambery' ),
				'label_block' 	=> true,
			]
		);
		
		// content
		$repeater->add_control(
			'accordion_content',
			[
				'label' 		=> __( 'Content', 'ambery' ),
				'default' 		=> __( 'Accordion Content', 'ambery' ),
				'placeholder'	=> __( 'Accordion Content', 'ambery' ),
				'type' 			=> Controls_Manager::WYSIWYG,
				'show_label' 	=> true,
			]
		);
		
		// items
		$this->add_control(
			'accordions',
			[
				'label' 	=> __( 'Accordion Items', 'ambery' ),
				'type' 		=> Controls_Manager::REPEATER,
				'fields' 	=> $repeater->get_controls(),
				'default' 	=> [
					[
						'accordion_number'	=> __( '01.', 'ambery' ),
						'accordion_title'	=> __( 'Accordion #1 Title', 'ambery' ),
						'accordion_content'	=> __( 'Accordion #1 Content', 'ambery' ),
					],
					[
						'accordion_number'	=> __( '02.', 'ambery' ),
						'accordion_title' 	=> __( 'Accordion #2 Title', 'ambery' ),
						'accordion_content'	=> __( 'Accordion #2 Content', 'ambery' ),
					],
					[
						'accordion_number'	=> __( '03.', 'ambery' ),
						'accordion_title' 	=> __( 'Accordion #3 Title', 'ambery' ),
						'accordion_content'	=> __( 'Accordion #3 Content', 'ambery' ),
					],
				],
				'title_field'	=> '{{{ accordion_title }}}',
			]
		);

		$this->add_control(
			'view',
			[
				'label' 	=> __( 'View', 'ambery' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
			
		$this->end_controls_section();
		// content control ends

		// section_accordion_style starts
		$this->start_controls_section(
			'section_accordion_style',
			[
				'label'	=> esc_html__( 'Styles', 'ambery' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'border_color',
			[
				'label' 	=> esc_html__( 'Border Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-accordion .accordion-item' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'icon_color',
			[
				'label' 	=> esc_html__( 'Icon Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .accordion-button::before, {{WRAPPER}} .accordion-button::after' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'accordion_title_control',
			[
				'label'	=> esc_html__( 'Title', 'ambery' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'accordion_number_color',
			[
				'label' 	=> esc_html__( 'Number Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-accordion-number' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'accordion_title_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-accordion .accordion-button' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'accordion_title_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector'	=> '{{WRAPPER}} .dtr-accordion .accordion-button',
            ]
        );
		
		$this->add_control(
			'accordion_content_control',
			[
				'label'	=> esc_html__( 'Content', 'ambery' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'accordion_content_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-accordion .accordion-body' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'accordion_content_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector'	=> '{{WRAPPER}} .dtr-accordion .accordion-body',
            ]
        );
		
		$this->end_controls_section();			
				
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		$accordions = $this->get_settings_for_display( 'accordions' );
		$id_int = substr( $this->get_id_int(), 0, 3 );
		$id_int_parent = substr( $this->get_id_int(), 0, 4 );
		if ( $id_int_parent != '' ) { 
			$accordion_ID = 'id=accordion-' . $id_int_parent . ''; 
			$accordion_parent_ID = 'data-bs-parent="#accordion-' . $id_int_parent . '"';
		} else {
			$accordion_ID = ''; 
			$accordion_parent_ID = ''; 
		}
		?>
        <div class="dtr-accordion accordion accordion-flush <?php echo $settings['accordion_icon_style']; ?>" <?php echo esc_attr( $accordion_ID ) ?>>
			<?php foreach ( $accordions as $index => $item ) : ?>
            <div class="accordion-item <?php echo $settings['show_number']; ?>">
				<?php $accordion_count = $index + 1;
                $accordion_title_setting_key = $this->get_repeater_setting_key( 'accordion_title', 'accordions', $index );
                $this->add_render_attribute( $accordion_title_setting_key, [
                    'class' 	=> [ 'accordion-button collapsed', 'clearfix' ],
                    'aria-controls' => 'dtr-accordion-content-' . $id_int . $accordion_count,
                ] );
                ?>
                <h4 class="dtr-accordion-title" id="<?php echo esc_attr( 'dtr-accordion-title-' . $id_int . $accordion_count ) ?>">
                    <a data-bs-toggle="collapse" data-bs-target="#<?php echo esc_attr( 'dtr-accordion-content-' . $id_int . $accordion_count ) ?>" <?php $this->print_render_attribute_string( $accordion_title_setting_key ); ?>>
                   <span class="dtr-accordion-number"><?php echo esc_html( $item['accordion_number'] ); ?></span> 
                   <?php if ( $item['accordion_title'] != '' ) { ?>
                   <span class="dtr-accordion-title-text"><?php echo esc_html( $item['accordion_title'] ); ?></span> 
                   <?php } ?>
                   </a>
                </h4>
				<?php
                $accordion_count = $index + 1; 
                $accordion_content_setting_key = $this->get_repeater_setting_key( 'accordion_content', 'accordions', $index );
                $this->add_render_attribute( $accordion_content_setting_key, [
                    'id' => 'dtr-accordion-content-' . $id_int . $accordion_count,
                    'class' => [ 'accordion-collapse collapse' ],
                    'aria-labelledby' => 'dtr-accordion-title-' . $id_int . $accordion_count,
                ] );
                $this->add_inline_editing_attributes( $accordion_content_setting_key, 'advanced' );
                ?>
                <div <?php $this->print_render_attribute_string( $accordion_content_setting_key ); ?> <?php echo esc_attr( $accordion_parent_ID ) ?>>
                    <div class="accordion-body">
                       <?php $this->print_text_editor( $item['accordion_content'] ); ?>
                    </div>
                </div>
        	</div>
         <?php endforeach; ?>
        </div>
		<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
        <# if ( settings.accordions ) {
        var accordionindex = view.getIDInt().toString().substr( 0, 3 );
        var accordionID = view.getIDInt().toString().substr( 0, 4 ); #>
        <div class="dtr-accordion accordion accordion-flush {{ settings.accordion_icon_style }}" id="accordion-{{ accordionID }}">
            <#
            _.each( settings.accordions, function( item, index ) {
            var accordionCount = index + 1;
            #>
                <div class="accordion-item {{ settings.show_number }}">
                    <h4 class="dtr-accordion-title" id="dtr-accordion-title-{{ accordionindex + accordionCount }}">
                    <a class="accordion-button collapsed" data-bs-toggle="collapse" data-bs-target="#dtr-accordion-content-{{ accordionindex + accordionCount }}" aria-controls="dtr-accordion-content-{{ accordionindex + accordionCount }}">
                     <span class="dtr-accordion-number">{{{ item.accordion_number }}}</span>
                     <span class="dtr-accordion-title-text">{{{ item.accordion_title }}}</span>
                    </a>
                    </h4>
                    <#
                    tabContentKey = view.getRepeaterSettingKey( 'accordion_content', 'accordions',index );
                    view.addRenderAttribute( tabContentKey, {
                    'id': 'dtr-accordion-content-' + accordionindex + accordionCount,
                    'class': [ 'accordion-collapse collapse' ],
                    'aria-labelledby': 'dtr-accordion-content-' + accordionindex + accordionCount,
                    } );
                    view.addInlineEditingAttributes( tabContentKey, 'advanced' ); #>
                    <div {{{ view.getRenderAttributeString( tabContentKey ) }}}" data-bs-parent="#accordion-{{ accordionID }}">
                    <div class="accordion-body">
                        <# if ( item.accordion_content ) { #>
                        {{{ item.accordion_content }}}
                        <# } #>
                    </div>
                    </div>
                </div>
            <# } ); #>
        </div>
        <# } #>
		<?php
	}
}