<?php
namespace AmberyAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Ambery_Blockquote extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-quote';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Blockquote', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_blockquote_content',
			[
				'label' => esc_html__( 'Blockquote', 'ambery' ),
			]
		);
		
		$this->add_control(
			'blockquote_style',
			[
				'label' => esc_html__( 'Quote Style', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-icon-quote dtr-icon-quote-center',
				'label_block' => true,
				'options' => [
					'dtr-icon-quote dtr-icon-quote-center'	=> esc_html__( 'Icon Quote - Center Aligned', 'ambery' ),
					'dtr-left-border-quote'					=> esc_html__( 'Left Border', 'ambery' ),
					'dtr-right-border-quote'				=> esc_html__( 'Right Border', 'ambery' ),
				],
			]
		);
		
		// Blockquote Text
		$this->add_control(
			'blockquote_content',
			[
				'label' => esc_html__( 'Blockquote Text', 'ambery' ),
				'description' => esc_html__('Use &lt;br&gt; tag for line break', 'ambery'),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__( 'Blockquote Text.', 'ambery' ),
				'placeholder' => esc_html__( 'Your Description', 'ambery' ),
				'title' => esc_html__( 'Blockquote Text Here', 'ambery' ),
				'separator' => 'none',
				'rows' => 10,
				'show_label' => true,
			]
		);
		
	
				
		// Source
		$this->add_control(
			'blockquote_source',
			[
				'label' => esc_html__( 'Source', 'ambery' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Source', 'ambery' ),
				'placeholder' => esc_html__( 'Source Here', 'ambery' ),
				'label_block' => true,
				'show_label' => true,
			]
		);
		
		$this->add_control(
			'view',
			[
				'label' => esc_html__( 'View', 'ambery' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_blockquote_style',
			[
				'label' => esc_html__( 'Styles', 'ambery' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'blockquote_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'ambery' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'separator'	=> 'before',
				'condition' => [
					'blockquote_style' => [ 'dtr-icon-quote dtr-icon-quote-center' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-icon-quote-center::before' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'blockquote_border_color',
			[
				'label' => esc_html__( 'Border Color', 'ambery' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
					'condition' => [
					'blockquote_style' => [ 'dtr-left-border-quote', 'dtr-right-border-quote' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-quote' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'blockquote_color',
			[
				'label' => esc_html__( 'Blockquote Text Color', 'ambery' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} blockquote' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'blockquote_typo',
				'label' 	=> esc_html__( 'Blockquote Text Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} blockquote',
            ]
        );
				
		$this->add_control(
			'blockquote_source_color',
			[
				'label' => esc_html__( 'Blockquote Source Color', 'ambery' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-quote-source' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'blockquote_source_typo',
				'label' 	=> esc_html__( 'Blockquote Source Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-quote-source',
            ]
        );

		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		$html = ''; 
		$html .= '<div class="dtr-quote ' . esc_attr( $settings['blockquote_style'] ) . ' clearfix">';
		if ( ! empty( $settings['blockquote_content'] ) ) {
			$html .= sprintf( '<blockquote>%s</blockquote>', wp_kses_post( $settings['blockquote_content'] ) );
		}
		if ( ! empty( $settings['blockquote_source'] ) ) {
			$html .= sprintf( '<span class="dtr-quote-source">%s</span>', esc_html( $settings['blockquote_source'] ) ); 
		}  
		$html .= '</div>';
		echo $html;	
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
		<#
		var html = '<div class="dtr-quote ' + settings.blockquote_style + ' clearfix">';
		if ( settings.blockquote_content ) {
			html += '<blockquote>' + settings.blockquote_content + '</blockquote>';
		}
		if ( settings.blockquote_source ) {
			html += '<span class="dtr-quote-source">' + settings.blockquote_source + '</span>';
		}
		html += '</div>';
		print( html );
		#>
		<?php
	}
}