<?php
namespace AmberyAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Ambery_Iconhead extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-iconhead';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Icon + Heading', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}
	
	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	
	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_iconhead',
			[
				'label' => __( 'Icon + Heading', 'ambery' ),
			]
		);
		
		$this->add_control(
			'iconhead_align_style',
			[
				'label' => esc_html__( 'Icon and Text Align', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-iconhead-left',
				'label_block' => true,
				'options' => [
					'dtr-iconhead-left'		=> esc_html__( 'Left', 'ambery' ),
					'dtr-iconhead-right' 	=> esc_html__( 'Right', 'ambery' ),
				],
			]
		);

		$this->add_control(
			'icon_size',
			[
				'label' => esc_html__( 'Icon Size', 'ambery' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 200,
					],
				],
				'default' => [
				'size' => 32,
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-iconhead-icon' => 'font-size: {{SIZE}}{{UNIT}}',
				],
			]
		);
		
		$this->add_control(
			'icon_margin',
			[
				'label' => esc_html__( 'Icon Margin Right', 'ambery' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 200,
					],
				],
				'default' => [
				'size' => 20,
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-iconhead-left .dtr-iconhead-icon' => 'margin-right: {{SIZE}}{{UNIT}}',
				],
				'condition' => [
					'iconhead_align_style'	=> [ 'dtr-iconhead-left' ],
				],
			]
		);
		
		$this->add_control(
			'icon_margin-left',
			[
				'label' => esc_html__( 'Icon Margin Left', 'ambery' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 200,
					],
				],
				'default' => [
				'size' => 20,
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-iconhead-right .dtr-iconhead-icon' => 'margin-left: {{SIZE}}{{UNIT}}',
				],
				'condition' => [
					'iconhead_align_style'	=> [ 'dtr-iconhead-right' ],
				],
			]
		);
		
		
		$this->add_control(
			'icon_library',
			[
				'label' => esc_html__( 'Icon Library', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-theme-custom-icons',
				'separator' => 'before',
				'label_block' => true,
				'options' => [
					'dtr-font-awesome-icons'	=> esc_html__( 'Font Awesome Library', 'ambery' ),
					'dtr-theme-custom-icons' 	=> esc_html__( 'Theme Custom Library', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'default_icon',
			[
				'label' => esc_html__( 'Font Awesome Library', 'ambery' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'fa-solid',
				],
				'label_block' => true,
				'condition' => [
					'icon_library' => [ 'dtr-font-awesome-icons' ],
				],
			]
		);

		// custom icons
		$this->add_control(
			'custom_icon',
			[
				'label' => esc_html__( 'Theme Custom Library', 'ambery' ),
				'type' => Controls_Manager::SELECT2,
				'default' => 'icon-star',
				'label_block' => true,
				'condition' => [
					'icon_library'	=> [ 'dtr-theme-custom-icons' ],
				],
				'description' => esc_html__( 'Icon demo file for extra icons is included in help document.', 'ambery' ),
				'options' => dtr_icons(),
			]
		);
		
		// heading
		$this->add_control(
			'heading',
			[
				'label' 		=> esc_html__( 'Heading', 'ambery' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Heading Goes Here', 'ambery' ),
				'placeholder' 	=> esc_html__( 'Heading Goes Here', 'ambery' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		);
				
		$this->add_control(
			'heading_size',
			[
				'label' 	=> esc_html__( 'Heading - HTML Tag', 'elementor' ),
				'type' 		=> Controls_Manager::SELECT,
				'options'	=> [
					'h1' 	=> 'H1',
					'h2' 	=> 'H2',
					'h3' 	=> 'H3',
					'h4' 	=> 'H4',
					'h5' 	=> 'H5',
					'h6'	=> 'H6',
					'p' 	=> 'p',
				],
				'default' => 'h4',
			]
		);

		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'ambery' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Styles', 'ambery' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Icon Color', 'ambery' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-iconhead' => 'color: {{VALUE}};',
				],
			]
		);
		
		// heading
		$this->add_control(
			'heading_style_control',
			[
				'label' 	=> esc_html__( 'Heading', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Heading', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-iconhead-heading'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'heading_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-iconhead-heading',
            ]
        );
	
		$this->end_controls_section();
	}

		/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		// icon
		if ( ! empty( $settings['custom_icon'] ) ) {
			$this->add_render_attribute( 'custom_icon', 'class', $settings['custom_icon'] );
			$this->add_render_attribute( 'custom_icon', 'aria-hidden', 'true' );
		}
		?>
        <div class="dtr-iconhead <?php echo esc_attr( $settings['iconhead_align_style'] ); ?>">
		<?php if ( $settings['icon_library'] == 'dtr-theme-custom-icons' && ! empty( $settings['default_icon'] ) ) { ?>
            <span class="dtr-iconhead-icon"><i <?php echo $this->get_render_attribute_string( 'custom_icon' ); ?>></i></span>
        <?php } else { ?>
            <span class="dtr-iconhead-icon"><?php Icons_Manager::render_icon( $settings['default_icon'], [ 'aria-hidden' => 'true' ] ); ?></span>
        <?php } ?>
        <?php if ( ! empty( $settings['heading'] ) ) { ?>
        	<<?php echo esc_attr( $settings['heading_size'] ) ?> class="dtr-iconhead-heading"><?php echo wp_kses_post( $settings['heading'] ); ?></<?php echo esc_attr( $settings['heading_size'] ) ?>>
        <?php } ?>
        </div>
<?php	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
        <# iconHTML = elementor.helpers.renderIcon( view, settings.default_icon, { 'aria-hidden': true }, 'i' , 'object' ); #>
        <div class="dtr-iconhead {{ settings.iconhead_align_style }}">
            <# if ( settings.icon_library == 'dtr-theme-custom-icons' ) { #>
                <span class="dtr-iconhead-icon"><i class="{{ settings.custom_icon }}"></i></span> 	
            <# } else {  #>
                <span class="dtr-iconhead-icon">{{{ iconHTML.value }}}</span>
            <#	} #>
            <{{ settings.heading_size }} class="dtr-iconhead-heading"> {{{ settings.heading }}}</{{ settings.heading_size }}>
        </div> 
		<?php
	}
}