<?php
namespace AmberyAddons\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * Image With Lightbox Widget
 */
class Ambery_Image_Lightbox extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-lightbox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Lightbox Image', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		  return array('dtr-element');

	}
	
	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// image control starts
		$this->start_controls_section(
			'section_lightbox_image',
			[
				'label'	=> esc_html__( 'Lightbox Image', 'ambery' ),
			]
		);

		// image
		$this->add_control(
			'lightbox_image_control',
			[
				'label' => esc_html__( 'Image', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);		
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'ambery' ),
				'type' 		=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> Utils::get_placeholder_image_src(),
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
			]
		);
		
		$this->add_control(
			'heading',
			[
				'label' 		=> esc_html__( 'Overlay Title', 'ambery' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( '', 'ambery' ),
				'placeholder' 	=> esc_html__( 'Overlay Title Goes Here', 'ambery' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		);
	
		$this->add_control(
			'gallery_ID',
			[
				'label' 		=> esc_html__( 'Gallery ID', 'ambery' ),
				'description'   => esc_html__( 'If need to open images in one lightbox, give same gallery ID to all those images.', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> '',
				'placeholder' 	=> '',
				'label_block'	=> true,
				'show_label'	=> true,
				'separator'		=> 'before',
			]
		);

		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'ambery' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label'	=> esc_html__( 'Styles', 'ambery' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'overlay_color',
			[
				'label' => esc_html__( 'Overlay Color', 'ambery' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-lightbox-img-overlay' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'ambery' ),
				'default' => '',
				'separator' => 'before',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-image-lightbox a::before' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
	$settings = $this->get_settings();
	?> 
    <div class="dtr-image-lightbox">
        <span class="dtr-lightbox-img-overlay"></span>
        <a data-elementor-open-lightbox="yes" data-elementor-lightbox-slideshow="<?php echo esc_attr( $settings['gallery_ID'] )?>" data-elementor-lightbox-title="<?php echo esc_attr( $settings['heading'] ); ?>" href="<?php echo esc_url( $settings['image']['url'] ) ?>" aria-label="lightbox"></a>
        <?php
        $this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
        $this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
        $this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
        $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' ); ?>
        <?php echo $image_html ?>
    </div>
<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
    <div class="dtr-image-lightbox"><span class="dtr-lightbox-img-overlay"></span> 
    <a data-elementor-open-lightbox="yes" data-elementor-lightbox-slideshow="{{{ settings.gallery_ID }}}" data-elementor-lightbox-title="{{ settings.heading }}" href="{{ image_url }}" aria-hidden="true"></a>
        <#	if ( settings.image.url ) { #>
        <#
        var image = {
        id: settings.image.id,
        url: settings.image.url,
        size: settings.thumbnail_size,
        dimension: settings.thumbnail_custom_dimension,
        model: view.getEditModel()
        };
        var image_url = elementor.imagesManager.getImageUrl( image );  #> <img src="{{ image_url }}"/>
        <# } #>
    </div>
<?php
	}
}