<?php
namespace AmberyAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Ambery_Info extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-info';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Info Table', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_info_table',
			[
				'label'	=> esc_html__( 'Info Table', 'ambery' ),
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'text',
			[
				'label' => __( 'Head Text', 'elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => __( 'Head Text', 'elementor' ),
				'default' => __( 'Head Text', 'elementor' ),
			]
		);
		
		$repeater->add_control(
			'content',
			[
				'label' => __( 'Content Text', 'elementor' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'placeholder' => __( 'Content Text', 'elementor' ),
				'default' => __( 'Content Text', 'elementor' ),
			]
		);
		
		$repeater->add_control(
			'link',
			[
				'label' => __( 'Wrap Content in link', 'elementor' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'elementor' ),
			]
		);
		
		$this->add_control(
			'info_table',
			[
				'label' => __( 'Items', 'elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'text' => __( 'Table Item #1', 'elementor' ),
					],
					[
						'text' => __( 'Table Item #2', 'elementor' ),
					],
					[
						'text' => __( 'Table Item #3', 'elementor' ),
					],
				],
				'title_field' => '{{{ text }}}',
			]
		);

		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'ambery' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_table_style',
			[
				'label'	=> esc_html__( 'Styles', 'ambery' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'head_style_control',
			[
				'label' => __( 'Head', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => '',
			]
		);
		
		$this->add_control(
			'head_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-info-table th'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'head_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector'	=> '{{WRAPPER}} .dtr-info-table th',
            ]
        );
		
		$this->add_control(
			'content_style_control',
			[
				'label' => __( 'Content', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-info-table td'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'content_link_color',
			[
				'label' 	=> esc_html__( 'Link Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-info-table td a'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		
		$this->add_control(
			'content_link_hover_color',
			[
				'label' 	=> esc_html__( 'Link Hover Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-info-table td a:hover'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'content_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector'	=> '{{WRAPPER}} .dtr-info-table td',
            ]
        );
		
		
		$this->add_control(
			'table_border_color',
			[
				'label' 	=> esc_html__( 'Border Bottom To Row Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'separator' => 'before',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-info-table th, {{WRAPPER}} .dtr-info-table td'	=> 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<table class="table dtr-info-table">
        	<tbody>
			<?php foreach ( $settings['info_table'] as $index => $item ) : ?>
            	<tr>
                	<th>
              		<?php echo  wp_kses_post( $item['text'] ); ?>
                  	</th>
                  	<td>
                    <?php
					if ( ! empty( $item['link']['url'] ) ) {
						$link_key = 'link_' . $index;
						$this->add_link_attributes( $link_key, $item['link'] );
						echo '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
					} 
					?>
                  		<?php echo wp_kses_post( $item['content'] ); ?>
                    <?php if ( ! empty( $item['link']['url'] ) ) : ?>
						</a>
					<?php endif; ?>
                  	</td>    
				</tr>	
			<?php endforeach; ?>
            </tbody>
		</table>
		<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
		<# if ( settings.info_table ) { #>
			<table class="table dtr-info-table">
            	<tbody>
				<# _.each( settings.info_table, function( item, index ) { #>
	                <tr>
                		<th>
                		{{{ item.text }}}
                		</th>
                		<td>
                        <# if ( item.link && item.link.url ) { #>
						<a href="{{ item.link.url }}">
						<# } #>
               				{{{ item.content }}} 
                        <# if ( item.link && item.link.url ) { #>
						</a>
						<# } #>
               			</td>
                	</tr>
				<#
				} ); #>
                </tbody>
			</table>
		<#	} #>
		<?php
	}
}