<?php
namespace AmberyAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Control_Media;
use Elementor\Group_Control_Image_Size;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Ambery_Infobox extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-infobox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Info Box', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_infobox_content',
			[
				'label'	=> esc_html__( 'Info Box', 'ambery' ),
			]
		);
		
		$this->add_responsive_control(
			'box_height',
			[
				'label' => esc_html__( 'Box Minimum Height', 'ambery' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 1000,
					],
				],
				'default' => [
				'size' => '300',
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-infobox' => 'min-height: calc({{SIZE}}{{UNIT}})',
				],
			]
		);
		
		// image
		$this->add_control(
			'team_image_control',
			[
				'label' => esc_html__( 'Image', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);		
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'ambery' ),
				'type' 		=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> AMBERY_ELEMENTOR_ADDONS_URL . 'assets/img/placeholder-icon.png',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
			]
		);
		
		// top heading
		$this->add_control(
			'infobox_top_heading',
			[
				'label' 		=> esc_html__( 'Top Heading', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Top Heading', 'ambery' ),
				'placeholder' 	=> esc_html__( 'Your Heading', 'ambery' ),
				'label_block' 	=> true,
				'separator'	 	=> 'before',
			]
		);
		
		// heading
		$this->add_control(
			'infobox_heading',
			[
				'label' 		=> esc_html__( 'Bottom Heading', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Bottom Heading', 'ambery' ),
				'placeholder' 	=> esc_html__( 'Your Heading', 'ambery' ),
				'label_block' 	=> true,
				'separator'	 	=> 'before',
			]
		);
		
		// heading
		$this->add_control(
			'infobox_subheading',
			[
				'label' 		=> esc_html__( 'Heading On Hover', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Inspire', 'ambery' ),
				'placeholder' 	=> esc_html__( 'Your SubHeading', 'ambery' ),
				'label_block' 	=> true,
				'separator'	 	=> 'before',
			]
		);
		
		// content
		$this->add_control(
			'infobox_content',
			[
				'label' 		=> esc_html__( 'Content', 'ambery' ),
				'type' 			=> Controls_Manager::WYSIWYG,
				'default' 		=> esc_html__( 'Lorem ipsum dolor sit amet consectetur adipiscing labore et dolore magna aliqua. ', 'ambery' ),
				'separator'		=> 'before',
				'placeholder' 	=> esc_html__( 'Your Content', 'ambery' ),
				'label_block' 	=> true,
			]
		);

		// link
		$this->add_control(
			'link_control',
			[
				'label' 	=> esc_html__( 'Link', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		
		
		// link display
		$this->add_control(
			'infobox_btn_display',
			[
				'label' 	=> esc_html__( 'Button', 'ambery' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> 'show',
				'options'	=> [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'	=> esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'ambery' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder'	=> 'http://your-link.com',
				'default' 		=> [
					'url'	=> '#',
				],
			]
		);

		$this->add_control(
			'btn_aria_label',
			[
				'label' 		=> esc_html__( 'Area label For Button', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Read More', 'ambery' ),
				'placeholder' 	=> esc_html__( 'Read More', 'ambery' ),
				'label_block' 	=> true,
				'separator'	 	=> 'before',
			]
		);
				
		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'ambery' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_infobox_style',
			[
				'label' => esc_html__( 'Styles', 'ambery' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		// background image
		$this->add_control(
			'bg_image_control',
			[
				'label' 	=> esc_html__( 'Background', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		
		
		$this->add_responsive_control(
			'bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-infobox'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_responsive_control(
			'bg_image',
			[
				'label' 		=> __( 'Background Image', 'ambery' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> AMBERY_ELEMENTOR_ADDONS_URL . 'assets/img/img-square-dark-600x300.png',
				],
				'selectors'		=> [
				'{{WRAPPER}} .dtr-infobox'	=> 'background-image: url("{{URL}}");',
			],
			
			]
		);
		
		$this->add_responsive_control(
			'bg_image_position',
			[
				'label' 	=> __( 'Background Position', 'ambery' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> 'center center',
				'options'	=> [
					'' 			=> _x( 'Default', 'Background Control', 'ambery' ),
				'top left' 		=> _x( 'Top Left', 'Background Control', 'ambery' ),
				'top center' 	=> _x( 'Top Center', 'Background Control', 'ambery' ),
				'top right' 	=> _x( 'Top Right', 'Background Control', 'ambery' ),
				'center left' 	=> _x( 'Center Left', 'Background Control', 'ambery' ),
				'center center'	=> _x( 'Center Center', 'Background Control', 'ambery' ),
				'center right' 	=> _x( 'Center Right', 'Background Control', 'ambery' ),
				'bottom left' 	=> _x( 'Bottom Left', 'Background Control', 'ambery' ),
				'bottom center' => _x( 'Bottom Center', 'Background Control', 'ambery' ),
				'bottom right' 	=> _x( 'Bottom Right', 'Background Control', 'ambery' ),
				],
				'selectors'	=> [
				'{{WRAPPER}} .dtr-infobox'	=> 'background-position: {{VALUE}};',
				],
			]
		);
		
		$this->add_responsive_control(
			'bg_image_repeat',
			[
				'label'		=> __( 'Background Repeat', 'ambery' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> 'no-repeat',
				'options'	=> [
					'' 		=> _x( 'Default', 'Background Control', 'ambery' ),
				'no-repeat'	=> _x( 'No-repeat', 'Background Control', 'ambery' ),
				'repeat' 	=> _x( 'Repeat', 'Background Control', 'ambery' ),
				'repeat-x'	=> _x( 'Repeat-x', 'Background Control', 'ambery' ),
				'repeat-y' 	=> _x( 'Repeat-y', 'Background Control', 'ambery' ),
				],
				'selectors' => [
				'{{WRAPPER}} .dtr-infobox'	=> 'background-repeat: {{VALUE}};',
				],
			]
		);
		
		$this->add_responsive_control(
			'bg_image_size',
			[
				'label' 	=> __( 'Background Repeat', 'ambery' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> 'cover',
				'options'	=> [
					''		=> _x( 'Default', 'Background Control', 'ambery' ),
				'auto' 		=> _x( 'Auto', 'Background Control', 'ambery' ),
				'cover' 	=> _x( 'Cover', 'Background Control', 'ambery' ),
				'contain'	=> _x( 'Contain', 'Background Control', 'ambery' ),
				],
				'selectors' => [
				'{{WRAPPER}} .dtr-infobox' => 'background-size: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'bg_hover_control',
			[
				'label' 	=> esc_html__( 'Background On Hover', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);	
		
		$this->add_control(
			'hover_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-infobox:hover::before'	=> 'background-color: {{VALUE}};',
				],
			]
		);	

		// Color
		$this->add_control(
			'heading_style_control',
			[
				'label' 	=> esc_html__( 'Heading / Content ', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Heading Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-infobox-title'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'hover_heading_color',
			[
				'label' 	=> esc_html__( ' On Hover heading / Content Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-infobox-subtitle, {{WRAPPER}} .dtr-infobox-desc'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'heading_typo',
				'label' 	=> esc_html__( 'Heading / On Hover heading Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-infobox-title, {{WRAPPER}} .dtr-infobox-subtitle',
            ]
        );
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'content_typo',
				'label' 	=> esc_html__( 'Content Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-infobox-desc',
            ]
        );

		// link
		$this->add_control(
			'link_style_control',
			[
				'label' 	=> esc_html__( 'Button', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'link_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-infobox-link'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'link_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-infobox-link'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'link_hover_bg_color',
			[
				'label' 	=> esc_html__( 'Hover Background Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-infobox-link:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'link_hover_color',
			[
				'label' 	=> esc_html__( 'Hover Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-infobox-link:hover' => 'color: {{VALUE}};',
				],
			]
		);
		
		
		$this->add_control(
			'bg_gradient_control',
			[
				'label' 	=> esc_html__( 'If need to change Top and Bottom gradient of background image', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'top_bg_gradient_control',
			[
				'label' 	=> esc_html__( 'Top gradient', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'top_overlay_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .dtr-infobox-top',
				'fields_options' => [
					'background' => [
						'default' => 'gradient',
					],
				],

			]
		);
		
		$this->add_control(
			'bottom_bg_gradient_control',
			[
				'label' 	=> esc_html__( 'Bottom gradient', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'bottom_overlay_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .dtr-infobox-bottom',
				'fields_options' => [
					'background' => [
						'default' => 'gradient',
					],
				],

			]
		);

		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); ?>
		
        <?php // icon
		if ( ! empty( $settings['custom_icon'] ) ) {
			$this->add_render_attribute( 'custom_icon', 'class', $settings['custom_icon'] );
			$this->add_render_attribute( 'custom_icon', 'aria-hidden', 'true' );
		} 

		// button
		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['link'] );
			$this->add_render_attribute( 'button', 'class', 'dtr-infobox-link' );
		}
		$this->add_render_attribute( 'button', 'role', 'button' ); ?>
        <div class="dtr-infobox-wrapper"><span class="dtr-infobox-top"></span><span class="dtr-infobox-bottom"></span>
            <div class="dtr-infobox">
                <div class="dtr-infobox-head">
				<?php if ( ! empty( $settings['image']['url'] ) ) { ?>
					<?php
                    $this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
                    $this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
                    $this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
                    $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' ); ?>
                    <?php echo $image_html ?>
                <?php } ?>
                <?php if ( ! empty( $settings['infobox_top_heading'] ) ) { ?>
                    <h6 class="dtr-infobox-top-title"><?php echo wp_kses_post( $settings['infobox_top_heading'] ) ?></h6>
                <?php } ?>
                </div>
            
                <?php if ( ! empty( $settings['infobox_heading'] ) ) { ?>
                    <h5 class="dtr-infobox-title"><?php echo wp_kses_post( $settings['infobox_heading'] ) ?></h5>
                <?php } ?>
                <div class="dtr-infobox-content">
                    <h5 class="dtr-infobox-subtitle"><?php echo wp_kses_post( $settings['infobox_heading'] ) ?></h5>
                    <?php if ( ! empty( $settings['infobox_content'] ) ) { ?>
                        <div class="dtr-infobox-desc"><?php echo wp_kses_post( $settings['infobox_content'] ) ?></div>
                    <?php } ?>
                </div>
            </div>
            <?php if ( $settings['infobox_btn_display'] == 'show' ) { ?>
                <a <?php echo $this->get_render_attribute_string( 'button' ); ?> aria-label="<?php echo esc_attr( $settings['btn_aria_label'] ) ?>"></a>
            <?php } ?>
        </div>
	<?php
		}
	
		/**
		 * Render widget output in the editor.
		 * Written as a Backbone JavaScript template and used to generate the live preview.
		 * @access protected
		 */
		protected function content_template() {
		?>
        <div class="dtr-infobox-wrapper">
            <div class="dtr-infobox"> 
            	
                 <div class="dtr-infobox-head">
            	 <#	if ( settings.image.url ) { #>
                    <#
                    var image = {
                    id: settings.image.id,
                    url: settings.image.url,
                    size: settings.thumbnail_size,
                    dimension: settings.thumbnail_custom_dimension,
                    model: view.getEditModel()
                    };
                    var image_url = elementor.imagesManager.getImageUrl( image );  #>
                    <img src="{{ image_url }}"/>
                <# } #>
                <# if ( settings.infobox_top_heading ) { #>
                    <h5 class="dtr-infobox-top-title">{{{ settings.infobox_top_heading }}}</h5>
                <# } #>
                </div>	
                 
                <# if ( settings.infobox_heading ) { #>
                    <h6 class="dtr-infobox-title">{{{ settings.infobox_heading }}}</h6>
                <# } #>
                <div class="dtr-infobox-content">   
                	<# if ( settings.infobox_subheading ) { #>
                    	<h6 class="dtr-infobox-subtitle">{{{ settings.infobox_subheading }}}</h6>
                	<# } #> 
                    <# if ( settings.infobox_content ) { #>
                        <div class="dtr-infobox-desc">{{{ settings.infobox_content }}}</div>
                    <# } #>
                </div>
            </div>
         	<# if ( settings.infobox_btn_display == 'show' ) { #>
               <a class="dtr-infobox-link" href="{{ settings.link.url }}" role="button"></a>
            <# } #>
        </div>
<?php
	}
}