<?php
namespace AmberyAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Single Recentposts Widget
 */
class Ambery_Single_Recentposts extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-posts-single';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Single Highlighted Post', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// content control starts
		$this->start_controls_section(
			'section_post_static_content',
			[
				'label' => esc_html__( 'Highlighted Post', 'ambery' ),
			]
		);
		
		$this->add_control(
			'post_orderby',
			[
				'label' => esc_html__( 'Sort Posts By', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => [
					'date' 	=> esc_html__( 'Date', 'ambery' ),
					'rand' 	=> esc_html__( 'Random', 'ambery' ),
					'title'	=> esc_html__( 'Title', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'post_order',
			[
				'label' => esc_html__( 'Arrange Sorted Posts', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => [
					'DESC'	=> esc_html__( 'Descending', 'ambery' ),
					'ASC'  	=> esc_html__( 'Ascending', 'ambery' ),
				],
			]
		);
		
		// selected post
		$this->add_control(
			'show_post_selected',
			[
				'label' => esc_html__( 'Show any selected post by ID', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'no',
				'separator' 	=> 'before',
				'options' => [
					'yes'	=> esc_html__( 'Yes', 'ambery' ),
					'no'  	=> esc_html__( 'No', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'post_selected',
			[
				'label' 		=> esc_html__( 'Post ID', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> '',
				'placeholder' 	=> '',
				'label_block'	=> true,
				'show_label'	=> true,
				'condition' => [
					'show_post_selected' => [ 'yes' ],
				],
				'description' 	=> esc_html__( 'Post ID is a number. Hover on post - edit - link to get this number. Refer online help document for more info.', 'ambery' ),
			]
		);
	
		// image
		$this->add_control(
			'image_settings',
			[
				'label' => esc_html__( 'Image Settings', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'image',
			[
				'label' => esc_html__( 'Image', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'  	=> esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'image_size',
			[
				'label' => esc_html__( 'Image Size', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'img_default',
				'options' => [
					'img_default'	=> esc_html__( 'Default', 'ambery' ),
					'img_custom'	=> esc_html__( 'Custom - Hard Crop', 'ambery' ),
				],
			]
		);
	
		$this->add_control(
			'image_size_default',
			[
				'label' => esc_html__( 'Choose Image Size', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'full',
				'condition' => [
					'image_size' => [ 'img_default' ],
				],
				'options' => [
					'full'		=> esc_html__( 'Full', 'ambery' ),
					'medium'	=> esc_html__( 'Medium', 'ambery' ),
					'thumbnail'	=> esc_html__( 'Thumbnail', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'img_crop_info',
			[
				'label' => esc_html__( 'While using cropping - size of main image must be greater than specified for cropping.', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'condition' => [
					'image_size' => [ 'img_custom' ],
				],
			]
		);
		
		$this->add_control(
			'img_width',
			[
				'label' => esc_html__( 'Hard Crop - Width ', 'ambery' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 600,
				'condition' => [
					'image_size' => [ 'img_custom' ],
				],
				'min' => 100,
				'step' => 10,
				'separator' => 'none',
			]
		);
		
		$this->add_control(
			'img_height',
			[
				'label' => esc_html__( 'Hard Crop - Height ', 'ambery' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 400,
				'condition' => [
					'image_size' => [ 'img_custom' ],
				],
				'min' => 100,
				'step' => 10,
				'separator' => 'none',
			]
		);	

		// content
		$this->add_control(
			'content_settings',
			[
				'label' => esc_html__( 'Content Settings', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'category',
			[
				'label' => esc_html__( 'Category', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'hide',
				'options' => [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'  	=> esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'date',
			[
				'label' => esc_html__( 'Date', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'  => esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'author',
			[
				'label' => esc_html__( 'Author', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'  => esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
					
		$this->add_control(
			'title',
			[
				'label' => esc_html__( 'Title', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'  	=> esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'excerpt',
			[
				'label' => esc_html__( 'Excerpt', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'  	=> esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'words',
			[
				'label' 		=> esc_html__( 'Limit Short Content - Words Count', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> '35',
				'label_block'	=> true,
				'show_label'	=> true,
				'condition' => [
					'excerpt' => [ 'show' ],
				],
			]
		);
		
		$this->add_control(
			'read_more',
			[
				'label' => esc_html__( 'Read More', 'insuran' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'separator' => 'before',
				'options' => [
					'show'	=> esc_html__( 'Show', 'insuran' ),
					'hide'	=> esc_html__( 'Hide', 'insuran' ),
				],
			]
		);
		
		// read_more_text
		$this->add_control(
			'read_more_text',
			[
				'label' 		=> esc_html__( 'Read More Text', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Read More', 'ambery' ),
				'label_block'	=> true,
				'show_label'	=> true,
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => esc_html__( 'Styles', 'ambery' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		// heading
		$this->add_control(
			'heading_style',
			[
				'label' => esc_html__( 'Heading', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' => esc_html__( 'Color', 'ambery' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-recentposts-title a' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'main_heading_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-recentposts-title a',
            ]
        );
		
		// Category
		$this->add_control(
			'category_style',
			[
				'label' 	=> esc_html__( 'Category', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'category_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'category_border_color',
			[
				'label' 	=> esc_html__( 'Border Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'category_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'category_icon_color',
			[
				'label' 	=> esc_html__( 'Icon Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a::before' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'category_hover_bg_color',
			[
				'label' 	=> esc_html__( 'Hover Background : Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'category_hover_border_color',
			[
				'label' 	=> esc_html__( 'Hover : Border Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'category_hover_color',
			[
				'label' 	=> esc_html__( 'Hover : Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a:hover, {{WRAPPER}} .dtr-meta-category a:hover::before' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'category_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-meta-category a',
            ]
        );
		
		// meta
		$this->add_control(
			'meta_style',
			[
				'label' 	=> esc_html__( 'Date / Author', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'meta_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta a' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'meta_border_color',
			[
				'label' 	=> esc_html__( 'Divider Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-item::after' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'meta_hover_color',
			[
				'label' 	=> esc_html__( 'Hover : Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'meta_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-meta a',
            ]
        );

		// Content
		$this->add_control(
			'content_style',
			[
				'label' => esc_html__( 'Content', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Excerpt Color', 'ambery' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-recentposts-excerpt' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'content_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-recentposts-excerpt',
            ]
        );
		
		// Read more
		$this->add_control(
			'read_more_style',
			[
				'label' => esc_html__( 'Read More', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'button_background_color',
			[
				'label' => __( 'Background Color', 'ambery' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn' => 'background-color: {{VALUE}};',
				],
			]
		);
				
		$this->add_control(
			'button_text_color',
			[
				'label' => __( 'Text Color', 'ambery' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_border_color',
			[
				'label' => __( 'Border Color', 'ambery' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_text_color',
			[
				'label' => __( 'Hover: Text Color', 'ambery' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_background_color',
			[
				'label' => __( 'Hover: Background Color', 'ambery' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'button_hover_border_color',
			[
				'label' => __( 'Hover: Border Color', 'ambery' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'button_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector'	=> '{{WRAPPER}} .dtr-btn-text',
            ]
        );

		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	 protected function render() {
		$settings = $this->get_settings_for_display();
		echo do_shortcode('[dtr_single_recentposts show_post_selected="' . $settings['show_post_selected'] . '" post_selected="' . $settings['post_selected'] . '" orderby="' . $settings['post_orderby'] . '" order="' . $settings['post_order'] . '" words="' . $settings['words'] . '" image="' . $settings['image'] . '" title="' . $settings['title'] . '" category="' . $settings['category'] . '" date="' . $settings['date'] . '" author="' . $settings['author'] . '" excerpt="' . $settings['excerpt'] . '" image_size="' . $settings['image_size'] . '" image_size_default="' . $settings['image_size_default'] . '" img_width="' . $settings['img_width'] . '" img_height="' . $settings['img_height'] . '" read_more="' . $settings['read_more'] . '" read_more_text="' . $settings['read_more_text'] . '" ]');
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() { }
}