<?php
namespace AmberyAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Static Recentposts Widget
 */
class Ambery_Static_Recentposts extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-posts-static';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Vertical Column Posts', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// content control starts
		$this->start_controls_section(
			'section_post_static_content',
			[
				'label' => esc_html__( 'Vertical Column Posts', 'ambery' ),
			]
		);
		
		$this->add_control(
			'post_limit',
			[
				'label' => esc_html__( 'Number of posts to show', 'ambery' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 3,
				'min' => 1,
				'max' => 4,
				'step' => 1,
				'separator' => 'before',
				'description' => esc_html__( 'min 1 to max 4', 'ambery' ),
			]
		);
		
		$this->add_control(
			'ignore_sticky',
			[
				'label' => esc_html__( 'Ignore Sticky Post', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'0' 	=> esc_html__( 'No', 'ambery' ),
					'1' 	=> esc_html__( 'Yes', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'post_orderby',
			[
				'label' => esc_html__( 'Sort Posts By', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => [
					'date' 	=> esc_html__( 'Date', 'ambery' ),
					'rand' 	=> esc_html__( 'Random', 'ambery' ),
					'title'	=> esc_html__( 'Title', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'post_order',
			[
				'label' => esc_html__( 'Arrange Sorted Posts', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => [
					'DESC'	=> esc_html__( 'Descending', 'ambery' ),
					'ASC'  	=> esc_html__( 'Ascending', 'ambery' ),
				],
			]
		);

		// content
		$this->add_control(
			'content_settings',
			[
				'label' => esc_html__( 'Content Settings', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'category',
			[
				'label' => esc_html__( 'Category', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'hide',
				'options' => [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'  	=> esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'date',
			[
				'label' => esc_html__( 'Date', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'  => esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'author',
			[
				'label' => esc_html__( 'Author', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'  => esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
					
		$this->add_control(
			'title',
			[
				'label' => esc_html__( 'Title', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'  	=> esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'heading_words',
			[
				'label' 		=> esc_html__( 'Limit Heading Text - Words Count', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> '10',
				'label_block'	=> true,
				'show_label'	=> true,
				'condition' => [
					'title' => [ 'show' ],
				],
			]
		);

		$this->add_control(
			'excerpt',
			[
				'label' => esc_html__( 'Excerpt', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'  	=> esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'words',
			[
				'label' 		=> esc_html__( 'Limit Short Content Words Count', 'xaasvik' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> '35',
				'label_block'	=> true,
				'show_label'	=> true,
				'condition' => [
					'excerpt' => [ 'show' ],
				],
			]
		);
		
		$this->add_control(
			'read_more',
			[
				'label' => esc_html__( 'Read More', 'insuran' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'separator' => 'before',
				'options' => [
					'show'	=> esc_html__( 'Show', 'insuran' ),
					'hide'	=> esc_html__( 'Hide', 'insuran' ),
				],
			]
		);
		
		// read_more_text
		$this->add_control(
			'read_more_text',
			[
				'label' 		=> esc_html__( 'Read More Text', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Read More', 'ambery' ),
				'label_block'	=> true,
				'show_label'	=> true,
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => esc_html__( 'Styles', 'ambery' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		// heading
		$this->add_control(
			'heading_style',
			[
				'label' => esc_html__( 'Heading', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' => esc_html__( 'Color', 'ambery' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-recentposts-title a' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'main_heading_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-recentposts-title a',
            ]
        );
		
		// Category
		$this->add_control(
			'category_style',
			[
				'label' 	=> esc_html__( 'Category', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'category_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'category_border_color',
			[
				'label' 	=> esc_html__( 'Border Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'category_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'category_icon_color',
			[
				'label' 	=> esc_html__( 'Icon Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a::before' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'category_hover_bg_color',
			[
				'label' 	=> esc_html__( 'Hover Background : Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'category_hover_border_color',
			[
				'label' 	=> esc_html__( 'Hover : Border Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'category_hover_color',
			[
				'label' 	=> esc_html__( 'Hover : Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-category a:hover, {{WRAPPER}} .dtr-meta-category a:hover::before' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'category_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-meta-category a',
            ]
        );
		
		// meta
		$this->add_control(
			'meta_style',
			[
				'label' 	=> esc_html__( 'Date / Author', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'meta_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta a' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'meta_border_color',
			[
				'label' 	=> esc_html__( 'Divider Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-item::after' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'meta_hover_color',
			[
				'label' 	=> esc_html__( 'Hover : Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'meta_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-meta a',
            ]
        );

		// Content
		$this->add_control(
			'content_style',
			[
				'label' => esc_html__( 'Content', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Excerpt Color', 'ambery' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-recentposts-excerpt' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'content_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-recentposts-excerpt',
            ]
        );
		
		// Read more
		$this->add_control(
			'read_more_style',
			[
				'label' => esc_html__( 'Read More', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'button_background_color',
			[
				'label' => __( 'Background Color', 'ambery' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn' => 'background-color: {{VALUE}};',
				],
			]
		);
				
		$this->add_control(
			'button_text_color',
			[
				'label' => __( 'Text Color', 'ambery' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_border_color',
			[
				'label' => __( 'Border Color', 'ambery' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_text_color',
			[
				'label' => __( 'Hover: Text Color', 'ambery' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_background_color',
			[
				'label' => __( 'Hover: Background Color', 'ambery' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'button_hover_border_color',
			[
				'label' => __( 'Hover: Border Color', 'ambery' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'button_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector'	=> '{{WRAPPER}} .dtr-btn-text',
            ]
        );

		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	 protected function render() {
		$settings = $this->get_settings_for_display();
		echo do_shortcode('[dtr_static_recentposts limit="' . $settings['post_limit'] . '" heading_words="' . $settings['heading_words'] . '" words="' . $settings['words'] . '" ignore_sticky="' . $settings['ignore_sticky'] . '" orderby="' . $settings['post_orderby'] . '" order="' . $settings['post_order'] . '" title="' . $settings['title'] . '" category="' . $settings['category'] . '" date="' . $settings['date'] . '" author="' . $settings['author'] . '" excerpt="' . $settings['excerpt'] . '" read_more="' . $settings['read_more'] . '" read_more_text="' . $settings['read_more_text'] . '" ]');
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() { }
}