<?php
namespace AmberyAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Section Intro Widget
 */
class Ambery_Section_Intro extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-section-intro';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Section Intro', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_section_intro_content',
			[
				'label'	=> esc_html__( 'Section Intro', 'ambery' ),
			]
		);
		
		// text align
		$this->add_control(
			'text_align',
			[
				'label' 	=> esc_html__( 'Text Align', 'ambery' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'text-left',
				'separator' => 'before',
				'options'	=> [
					'text-center'	=> esc_html__( 'Center', 'ambery' ),
					'text-left'		=> esc_html__( 'Left', 'ambery' ),
					'text-right'	=> esc_html__( 'Right', 'ambery' ),
				],
			]
		);

		// heading
		$this->add_control(
			'heading',
			[
				'label' 		=> esc_html__( 'Heading', 'ambery' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Heading Goes Here', 'ambery' ),
				'placeholder' 	=> esc_html__( 'Heading Goes Here', 'ambery' ),
				'label_block'	=> true,
				'show_label'	=> true,
			]
		);
				
		$this->add_control(
			'heading_size',
			[
				'label' 	=> esc_html__( 'Heading - HTML Tag', 'elementor' ),
				'type' 		=> Controls_Manager::SELECT,
				'options'	=> [
					'h1' 	=> 'H1',
					'h2' 	=> 'H2',
					'h3' 	=> 'H3',
					'h4' 	=> 'H4',
					'h5' 	=> 'H5',
					'h6'	=> 'H6',
					'p' 	=> 'p',
				],
				'default' => 'h2',
			]
		);
		
		// subheading
		$this->add_control(
			'subheading',
			[
				'label' 		=> esc_html__( 'Sub Heading', 'ambery' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Sub Heading', 'ambery' ),
				'placeholder' 	=> esc_html__( 'Sub Heading Goes Here', 'ambery' ),
				'label_block'	=> true,
				'show_label'	=> true,
			]
		);
		
		$this->add_control(
			'sub_heading_size',
			[
				'label' 	=> esc_html__( 'Sub Heading - HTML Tag', 'elementor' ),
				'type' 		=> Controls_Manager::SELECT,
				'options'	=> [
					'h1' 	=> 'H1',
					'h2' 	=> 'H2',
					'h3' 	=> 'H3',
					'h4' 	=> 'H4',
					'h5' 	=> 'H5',
					'h6'	=> 'H6',
					'p' 	=> 'p',
				],
				'default' => 'p',
			]
		);
		
		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'ambery' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_section_intro_style',
			[
				'label'	=> esc_html__( 'Styles', 'ambery' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		// heading
		$this->add_control(
			'heading_style_control',
			[
				'label'	=> esc_html__( 'Heading', 'ambery' ),
				'type' 	=> Controls_Manager::HEADING,
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-styled-heading-heading'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'heading_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector'	=> '{{WRAPPER}} .dtr-styled-heading-heading',
            ]
        );
		
		// subheading
		$this->add_control(
			'subheading_style_control',
			[
				'label'	=> esc_html__( 'Sub Heading', 'ambery' ),
				'type' 	=> Controls_Manager::HEADING,
			]
		);
		
		$this->add_control(
			'subheading_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-styled-heading-subheading'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'subheading_border_color',
			[
				'label' 	=> esc_html__( 'Border Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-styled-heading-subheading, {{WRAPPER}} .dtr-styled-heading-subheading::before'	=> 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'subheading_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector'	=> '{{WRAPPER}} .dtr-styled-heading-subheading',
            ]
        );
		
		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
	$settings = $this->get_settings(); ?>
    
    <div class="dtr-styled-heading <?php echo esc_attr( $settings['text_align'] ) ?>">
        <?php if ( ! empty( $settings['heading'] ) ) { ?>
        	<<?php echo esc_attr( $settings['heading_size'] ) ?> class="dtr-styled-heading-heading"><?php echo wp_kses_post( $settings['heading'] ) ?></<?php echo esc_attr( $settings['heading_size'] ) ?>>
        <?php } ?>
        <?php if ( ! empty( $settings['subheading'] ) ) { ?>
            <<?php echo esc_attr( $settings['sub_heading_size'] ) ?> class="dtr-styled-heading-subheading"><?php echo wp_kses_post( $settings['subheading'] ); ?></<?php echo esc_attr( $settings['sub_heading_size'] ) ?>>
        <?php } ?>
    </div>
<?php }

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
        <#
		var html = '';
        html += '<div class="dtr-styled-heading ' + settings.text_align + '">';
        if ( settings.heading ) {
            html += '<' + settings.heading_size + ' class="dtr-styled-heading-heading">' + settings.heading + '</' + settings.heading_size + '>';
        }
        if ( settings.subheading ) {
            html += '<' + settings.sub_heading_size + ' class="dtr-styled-heading-subheading">' + settings.subheading + '</' + settings.sub_heading_size + '>';
        }	
        html += '</div>';
		print( html );
		#>
		<?php
	}
}