<?php
namespace AmberyAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Control_Media;
use Elementor\Group_Control_Image_Size;
use Elementor\Icons_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Ambery_Servicebox extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-servicebox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service Box', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_servicebox_content',
			[
				'label'	=> esc_html__( 'Service Box', 'ambery' ),
			]
		);
		
		$this->add_control(
			'servicebox_icon_control',
			[
				'label' 	=> esc_html__( 'Image / Icon Settings', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'servicebox_icon_type',
			[
				'label' 	=> esc_html__( 'Type', 'ambery' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> 'dtr-servicebox-type-icon',
				'options' 	=> [
					'dtr-servicebox-type-img'	=> esc_html__( 'Image', 'ambery' ),
					'dtr-servicebox-type-icon'	=> esc_html__( 'Icon', 'ambery' ),
					'dtr-servicebox-type-html'	=> esc_html__( 'Custom HTML', 'ambery' ),
				],
			]
		);
		
		// html
		$this->add_control(
			'servicebox_image_html',
			[
				'label' => __( 'Custom HTML', 'ambery' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => '',
				'label_block' => true,
				'condition' => [
					'servicebox_icon_type'	=> [ 'dtr-servicebox-type-html' ],
				],
			]
		);
		
		// image
		$this->add_control(
			'servicebox_image_control',
			[
				'label' 	=> esc_html__( 'Image', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
				'condition' => [
					'servicebox_icon_type'	=> [ 'dtr-servicebox-type-img' ],
				],
			]
		);		
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'ambery' ),
				'type' 		=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> AMBERY_ELEMENTOR_ADDONS_URL . 'assets/img/img-circle-100x100.png',
				],
				'condition'	=> [
					'servicebox_icon_type'	=> [ 'dtr-servicebox-type-img' ],
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
				'condition' => [
					'servicebox_icon_type'	=> [ 'dtr-servicebox-type-img' ],
				],
			]
		);
		
	$this->add_control(
			'icon_library',
			[
				'label' => esc_html__( 'Icon Library', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-font-awesome-icons',
				'label_block' => true,
				'options' => [
					'dtr-font-awesome-icons'	=> esc_html__( 'Font Awesome Library', 'ambery' ),
					'dtr-theme-custom-icons' 	=> esc_html__( 'Theme Custom Library', 'ambery' ),
				],
				'condition'	=> [
					'servicebox_icon_type'	=> [ 'dtr-servicebox-type-icon' ],
				],
			]
		);
		
		$this->add_control(
			'default_icon',
			[
				'label' => esc_html__( 'Font Awesome Library', 'ambery' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'fa-solid',
				],
				'label_block' => true,
				'condition' => [
					'servicebox_icon_type'	=> [ 'dtr-servicebox-type-icon' ],
					'icon_library' 			=> [ 'dtr-font-awesome-icons' ],
				],
			]
		);


		// custom icons
		$this->add_control(
			'custom_icon',
			[
				'label' => esc_html__( 'Theme Custom Library', 'ambery' ),
				'type' => Controls_Manager::SELECT2,
				'default' => 'icon-star',
				'label_block' => true,
				'condition' => [
					'servicebox_icon_type'	=> [ 'dtr-servicebox-type-icon' ],
					'icon_library'			=> [ 'dtr-theme-custom-icons' ],
				],
				'description' => esc_html__( 'Icon demo file for extra icons is included in help document.', 'ambery' ),
				'options' => dtr_icons(),
			]
		);
		
		// heading
		$this->add_control(
			'servicebox_heading',
			[
				'label' 		=> esc_html__( 'Heading', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Inspire', 'ambery' ),
				'placeholder' 	=> esc_html__( 'Your Heading', 'ambery' ),
				'label_block' 	=> true,
				'separator'	 	=> 'before',
			]
		);
		
		// content
		$this->add_control(
			'servicebox_content',
			[
				'label' 		=> esc_html__( 'Content', 'ambery' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Lorem ipsum dolor sit amet consectetur adipiscing labore et dolore magna aliqua. ', 'ambery' ),
				'separator'		=> 'before',
				'placeholder' 	=> esc_html__( 'Your Content', 'ambery' ),
				'label_block' 	=> true,
			]
		);

		// link
		$this->add_control(
			'link_control',
			[
				'label' 	=> esc_html__( 'Link', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		
		
		// link display
		$this->add_control(
			'servicebox_btn_display',
			[
				'label' 	=> esc_html__( 'Button', 'ambery' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> 'show',
				'options'	=> [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'	=> esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'ambery' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder'	=> 'http://your-link.com',
				'default' 		=> [
					'url'	=> '#',
				],
			]
		);
		
		$this->add_control(
			'btn_aria_label',
			[
				'label' 		=> esc_html__( 'Area label For Button', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Read More', 'ambery' ),
				'placeholder' 	=> esc_html__( 'Read More', 'ambery' ),
				'label_block' 	=> true,
				'separator'	 	=> 'before',
			]
		);
				
		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'ambery' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_servicebox_style',
			[
				'label' => esc_html__( 'Styles', 'ambery' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'box_border_color',
			[
				'label' 	=> esc_html__( 'Border Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox'	=> 'border-color: {{VALUE}};',
				],
			]
		);

		// background image
		$this->add_control(
			'bg_image_control',
			[
				'label' 	=> esc_html__( 'Background', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		
		
		$this->add_control(
			'bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'bg_image_hover_control',
			[
				'label' 	=> esc_html__( 'Background On Hover', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);	
		
		$this->add_control(
			'hover_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox:hover'	=> 'background-color: {{VALUE}};',
				],
			]
		);	
		
		$this->add_control(
			'hover_bg_image',
			[
				'label' 		=> __( 'Background Image', 'ambery' ),
				'type' 			=> Controls_Manager::MEDIA,
				'selectors'		=> [
				'{{WRAPPER}} .dtr-servicebox:hover'	=> 'background-image: url("{{URL}}");',
			],
			
			]
		);
		
		$this->add_control(
			'hover_bg_image_position',
			[
				'label' 	=> __( 'Background Position', 'ambery' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> '',
				'options'	=> [
					'' 			=> _x( 'Default', 'Background Control', 'ambery' ),
				'top left' 		=> _x( 'Top Left', 'Background Control', 'ambery' ),
				'top center' 	=> _x( 'Top Center', 'Background Control', 'ambery' ),
				'top right' 	=> _x( 'Top Right', 'Background Control', 'ambery' ),
				'center left' 	=> _x( 'Center Left', 'Background Control', 'ambery' ),
				'center center'	=> _x( 'Center Center', 'Background Control', 'ambery' ),
				'center right' 	=> _x( 'Center Right', 'Background Control', 'ambery' ),
				'bottom left' 	=> _x( 'Bottom Left', 'Background Control', 'ambery' ),
				'bottom center' => _x( 'Bottom Center', 'Background Control', 'ambery' ),
				'bottom right' 	=> _x( 'Bottom Right', 'Background Control', 'ambery' ),
				],
				'selectors'	=> [
				'{{WRAPPER}} .dtr-servicebox:hover'	=> 'background-position: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'hover_bg_image_repeat',
			[
				'label'		=> __( 'Background Repeat', 'ambery' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> '',
				'options'	=> [
					'' 		=> _x( 'Default', 'Background Control', 'ambery' ),
				'no-repeat'	=> _x( 'No-repeat', 'Background Control', 'ambery' ),
				'repeat' 	=> _x( 'Repeat', 'Background Control', 'ambery' ),
				'repeat-x'	=> _x( 'Repeat-x', 'Background Control', 'ambery' ),
				'repeat-y' 	=> _x( 'Repeat-y', 'Background Control', 'ambery' ),
				],
				'selectors' => [
				'{{WRAPPER}} .dtr-servicebox:hover'	=> 'background-repeat: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'hover_bg_image_size',
			[
				'label' 	=> __( 'Background Size', 'ambery' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> '',
				'options'	=> [
					''		=> _x( 'Default', 'Background Control', 'ambery' ),
				'auto' 		=> _x( 'Auto', 'Background Control', 'ambery' ),
				'cover' 	=> _x( 'Cover', 'Background Control', 'ambery' ),
				'contain'	=> _x( 'Contain', 'Background Control', 'ambery' ),
				],
				'selectors' => [
				'{{WRAPPER}} .dtr-servicebox:hover' => 'background-size: {{VALUE}};',
				],
			]
		);
		
		// icon
		$this->add_control(
			'icon_color',
			[
				'label' 	=> esc_html__( 'Icon Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'separator'	=> 'before',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox-icon'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'hover_icon_color',
			[
				'label' 	=> esc_html__( 'On Box Hover : Icon Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox:hover .dtr-servicebox-icon'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		// icon
		$this->add_control(
			'icon_bg_color',
			[
				'label' 	=> esc_html__( 'Offset Circle Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'separator'	=> 'before',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox-icon::before'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'hover_icon_bg_color',
			[
				'label' 	=> esc_html__( 'On Box Hover : Offset Circle Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox:hover .dtr-servicebox-icon::before'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		// heading
		$this->add_control(
			'heading_style_control',
			[
				'label' 	=> esc_html__( 'Heading', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Heading', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox-heading'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'hover_heading_color',
			[
				'label' 	=> esc_html__( 'On Box Hover : Heading', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox:hover .dtr-servicebox-heading'	=> 'color: {{VALUE}};',
				],
			]
		);
	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'heading_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-servicebox-heading',
            ]
        );

		// content
		$this->add_control(
			'content_style_control',
			[
				'label' 	=> esc_html__( 'Content', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' 	=> esc_html__( 'Content', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox-content'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'hover_content_color',
			[
				'label' 	=> esc_html__( 'On Box Hover : Content', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox:hover .dtr-servicebox-content'	=> 'color: {{VALUE}};',
				],
			]
		);
	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'content_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-servicebox-content',
            ]
        );

		// content
		$this->add_control(
			'link_style_control',
			[
				'label' 	=> esc_html__( 'Button', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'link_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox-link'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'link_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox-link'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'link_hover_bg_color',
			[
				'label' 	=> esc_html__( 'Hover Background Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox-link:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'link_hover_color',
			[
				'label' 	=> esc_html__( 'Hover Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox-link:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		
		// helper classes
		if ( $settings['servicebox_icon_type'] == 'dtr-servicebox-type-img' || $settings['servicebox_icon_type'] == 'dtr-servicebox-type-html' ) {
			$no_cirlce = 'has-no-circle-bg'	;
		} else { $no_cirlce = ''; }
		
		// icon
		if ( ! empty( $settings['custom_icon'] ) ) {
			$this->add_render_attribute( 'custom_icon', 'class', $settings['custom_icon'] );
			$this->add_render_attribute( 'custom_icon', 'aria-hidden', 'true' );
		} 

		// button
		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['link'] );
			$this->add_render_attribute( 'button', 'class', 'dtr-servicebox-link' );
		}
		$this->add_render_attribute( 'button', 'role', 'button' ); ?>
        <div class="dtr-servicebox <?php echo esc_attr( $no_cirlce ) ?>">
        	<div class="dtr-servicebox-head">
                <div class="dtr-servicebox-icon">  
                <?php if ( $settings['servicebox_icon_type'] == 'dtr-servicebox-type-icon' ) { 
                        if ( $settings['icon_library'] == 'dtr-theme-custom-icons' ) { ?>
                            <i <?php echo $this->get_render_attribute_string( 'custom_icon' ); ?>></i>
                        <?php } else { ?>
                            <?php Icons_Manager::render_icon( $settings['default_icon'], [ 'aria-hidden' => 'true' ] ); 
                        } 
                    } elseif ( $settings['servicebox_icon_type'] == 'dtr-servicebox-type-html' ) { 
                        echo wp_kses_post( $settings['servicebox_image_html'] );       
                    } elseif ( $settings['servicebox_icon_type'] == 'dtr-servicebox-type-img' && ! empty( $settings['image']['url'] ) ) {
                        $this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
                        $this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
                        $this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
                        $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' ); 
                        echo $image_html;
                } else {} ?>
                </div>
                <?php if ( ! empty( $settings['servicebox_heading'] ) ) { ?>
                    <h4 class="dtr-servicebox-heading"><?php echo wp_kses_post( $settings['servicebox_heading'] ) ?></h4>
                <?php } ?>
            </div>
            <?php if ( ! empty( $settings['servicebox_content'] ) ) { ?>
                <div class="dtr-servicebox-content"><?php echo wp_kses_post( $settings['servicebox_content'] ) ?></div>
            <?php } ?>
            <?php if ( $settings['servicebox_btn_display'] == 'show' ) { ?>
                <p><a <?php echo $this->get_render_attribute_string( 'button' ); ?> aria-label="<?php echo esc_attr( $settings['btn_aria_label'] ) ?>"></a></p>
            <?php } ?>
        </div>
	<?php
		}
	
		/**
		 * Render widget output in the editor.
		 * Written as a Backbone JavaScript template and used to generate the live preview.
		 * @access protected
		 */
		protected function content_template() {
		?>
        <# if ( settings.servicebox_icon_type == 'dtr-servicebox-type-img' || settings.servicebox_icon_type == 'dtr-servicebox-type-html' ) {
			$no_circle = 'has-no-circle-bg';
		} else { 
			$no_circle = ''; 
		} #>
        <div class="dtr-servicebox {{ $no_circle }}">  
        	<div class="dtr-servicebox-head">	   
                <div class="dtr-servicebox-icon">
                    <# iconHTML = elementor.helpers.renderIcon( view, settings.default_icon, { 'aria-hidden': true }, 'i' , 'object' ); #>
                    <# if( settings.servicebox_icon_type == 'dtr-servicebox-type-icon' ) {
                        if ( settings.icon_library == 'dtr-theme-custom-icons' ) { #>
                            <i class="{{ settings.custom_icon }}"></i> 	
                        <# } else {  #>
                            {{{ iconHTML.value }}}	
                        <#	} #>
                    <# } else { #>
                        <# if( settings.servicebox_icon_type == 'dtr-servicebox-type-img' ) { #>
                            <# var image = {
                            id: settings.image.id,
                            url: settings.image.url,
                            size: settings.thumbnail_size,
                            dimension: settings.thumbnail_custom_dimension,
                            model: view.getEditModel()
                            };
                            var image_url = elementor.imagesManager.getImageUrl( image ); #>  
                            <img src="{{ image_url }}"/>
                       <# } else { #>	
                          {{{ settings.servicebox_image_html }}}   
                       <# } #>	     
                     <# } #>	
                </div>
                <# if ( settings.servicebox_heading ) { #>
                    <h4 class="dtr-servicebox-heading">{{{ settings.servicebox_heading }}}</h4>
                <# } #>
            </div>  
                  
            <# if ( settings.servicebox_content ) { #>
                <div class="dtr-servicebox-content">{{{ settings.servicebox_content }}}</div>
            <# } #>
            
            <# if ( settings.servicebox_btn_display == 'show' ) { #>
               <p><a class="dtr-servicebox-link" href="{{ settings.link.url }}" role="button"></a></p>
            <# } #>
        </div>
<?php
	}
}