<?php
namespace AmberyAddons\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * Single Image Widget
 */
class Ambery_Single_Image extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-single-image';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Portfolio Featured Item', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		  return array('dtr-element');

	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// image control starts
		$this->start_controls_section(
			'section_single_image_image',
			[
				'label'	=> esc_html__( 'Single Image', 'ambery' ),
			]
		);

		// image
		$this->add_control(
			'single_image_image_control',
			[
				'label' => esc_html__( 'Image', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);		
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'ambery' ),
				'type' 		=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> Utils::get_placeholder_image_src(),
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
			]
		);
		// title
		$this->add_control(
			'single_image_title',
			[
				'label' 		=> esc_html__( 'Title', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Title Goes Here', 'ambery' ),
				'placeholder'	=> esc_html__( 'Title', 'ambery' ),
				'label_block' 	=> true,
				'separator' 	=> 'before',
			]
		);
		
		// location
		$this->add_control(
			'single_image_location',
			[
				'label' 		=> esc_html__( 'Location', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Location Text Goes Here', 'ambery' ),
				'placeholder'	=> esc_html__( 'Location', 'ambery' ),
				'label_block' 	=> true,
			]
		);
		
		// subtext
		$this->add_control(
			'single_image_subtext',
			[
				'label' 		=> esc_html__( 'Sub Text', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Sub text Goes Here', 'ambery' ),
				'placeholder'	=> esc_html__( 'Sub Text', 'ambery' ),
				'label_block' 	=> true,
			]
		);
		
		// link
		$this->add_control(
			'link_control',
			[
				'label' 	=> esc_html__( 'Link To Icon', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		
		
		$this->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'ambery' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder'	=> 'http://your-link.com',
				'default' 		=> [
					'url'	=> '#',
				],
			]
		);
		
		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'ambery' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label'	=> esc_html__( 'Styles', 'ambery' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'overlay_color',
			[
				'label' => esc_html__( 'Overlay Color', 'ambery' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-single-img-overlay' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'link_color',
			[
				'label' => esc_html__( 'Link Icon Color', 'ambery' ),
				'default' => '',
				'separator' => 'before',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-media-link, {{WRAPPER}} .dtr-media-link:hover' => 'color: {{VALUE}};',
				],
			]
		);

		// heading
		$this->add_control(
			'heading_style',
			[
				'label' => esc_html__( 'Heading', 'ambery' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-single-img-heading, {{WRAPPER}} .dtr-single-img-heading a'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'main_heading_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector'	=> '{{WRAPPER}} .dtr-single-img-heading, {{WRAPPER}} .dtr-single-img-heading a',
            ]
        );
		
		// location
		$this->add_control(
			'location_style',
			[
				'label' => esc_html__( 'Location', 'ambery' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'location_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-single-img-location'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'location_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector'	=> '{{WRAPPER}} .dtr-single-img-location',
            ]
        );
		
		// desc
		$this->add_control(
			'desc_style',
			[
				'label' => esc_html__( 'Description', 'ambery' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'desc_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-single-img-desc'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'desc_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector'	=> '{{WRAPPER}} .dtr-single-img-desc',
            ]
        );
		
		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		// button
		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['link'] );
		}
		$this->add_render_attribute( 'button', 'role', 'button' ); 
	  ?>
<div class="dtr-single-img"> <span class="dtr-single-img-overlay"></span>
    <?php if ( ! empty( $settings['image']['url'] ) ) { ?>
    <div class="dtr-single-img-img"> 
		<?php if ( ! empty( $settings['link']['url'] ) ) { ?>
            <a class="dtr-media-link" <?php echo $this->get_render_attribute_string( 'button' ); ?> aria-label="<?php echo esc_html( $settings['single_image_title'] ) ?>"></a>
        <?php } ?>
        <?php
		$this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
		$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
		$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
		$image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' ); ?>
        <?php echo $image_html ?> </div>
    <?php } ?>
    <div class="dtr-single-img-content">
        <?php if ( ! empty( $settings['single_image_title'] ) ) { ?>
        <h5 class="dtr-single-img-heading">
			<?php if ( ! empty( $settings['link']['url'] ) ) { ?>
                <a <?php echo $this->get_render_attribute_string( 'button' ); ?>>
            <?php } ?>
            	<?php echo esc_html( $settings['single_image_title'] ) ?>
            <?php if ( ! empty( $settings['link']['url'] ) ) { ?>
                </a>
            <?php } ?>
        </h5>
        <?php } ?>
        <?php if ( ! empty( $settings['single_image_location'] ) ) { ?>
        <p class="dtr-single-img-location"><?php echo esc_html( $settings['single_image_location'] ) ?></p>
        <?php } ?>
        <?php if ( ! empty( $settings['single_image_subtext'] ) ) { ?>
        <p class="dtr-single-img-desc"><?php echo esc_html( $settings['single_image_subtext'] ) ?></p>
        <?php } ?>
    </div>
</div>
<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
<div class="dtr-single-img"><span class="dtr-single-img-overlay"></span> <#	if ( settings.image.url ) { #>
    <div class="dtr-single-img-img"> 
    	<#	if ( settings.link.url ) { #>
        <a class="dtr-media-link" href="{{ settings.link.url }}" role="button"></a>
        <# } #>
        <#
        var image = {
        id: settings.image.id,
        url: settings.image.url,
        size: settings.thumbnail_size,
        dimension: settings.thumbnail_custom_dimension,
        model: view.getEditModel()
        };
        var image_url = elementor.imagesManager.getImageUrl( image );  #> <img src="{{ image_url }}"/> </div>
    <# } #>
    <div class="dtr-single-img-content"> <# if ( settings.single_image_title ) { #>
        <h5 class="dtr-single-img-heading">
        <#	if ( settings.link.url ) { #>
        	<a href="{{ settings.link.url }}">
        <# } #>
        	{{{settings.single_image_title }}}
        <#	if ( settings.link.url ) { #>
        	</a>
        <# } #>
        </h5>
        <# } #>
        <# if ( settings.single_image_location ) { #>
        <p class="dtr-single-img-location">{{{settings.single_image_location }}}</p>
        <# } #>
        <# if ( settings.single_image_subtext ) { #>
        <p class="dtr-single-img-desc">{{{settings.single_image_subtext }}}</p>
        <# } #> </div>
</div>
<?php
	}
}