<?php
namespace AmberyAddons\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * Widget
 */
class Ambery_Static_Infobox extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-static-infobox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Static Infobox', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		  return array('dtr-element');

	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// image control starts
		$this->start_controls_section(
			'section_infobox_img',
			[
				'label'	=> esc_html__( 'Static Infobox', 'ambery' ),
			]
		);
		
		// image
		$this->add_control(
			'image_control',
			[
				'label' => esc_html__( 'Image', 'ambery' ),
				'type' => Controls_Manager::HEADING,
			]
		);		
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'ambery' ),
				'type' 		=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> Utils::get_placeholder_image_src(),
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
			]
		);
		
		// title
		$this->add_control(
			'infobox_title',
			[
				'label' 		=> esc_html__( 'Title', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Title Goes Here', 'ambery' ),
				'placeholder'	=> esc_html__( 'Title', 'ambery' ),
				'label_block' 	=> true,
				'separator' 	=> 'before',
			]
		);
		
		// sub title
		$this->add_control(
			'infobox_sub_title',
			[
				'label' 		=> esc_html__( 'Sub Title', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Sub Title', 'ambery' ),
				'placeholder'	=> esc_html__( 'Sub Title', 'ambery' ),
				'label_block' 	=> true,
			]
		);
	
		
		// link
		$this->add_control(
			'link_control',
			[
				'label' 	=> esc_html__( 'Wrap box in a Link', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		

		$this->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'ambery' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder'	=> 'http://your-link.com',
				'default' 		=> [
					'url'	=> '',
				],
			]
		);
	
		$this->end_controls_section();

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label'	=> esc_html__( 'Styles', 'ambery' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'overlay_style',
			[
				'label' => esc_html__( 'Overlay', 'ambery' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'overlay_bg_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .dtr-static-infobox-overlay',
				'fields_options' => [
					'background' => [
						'default' => 'gradient',
					],
				],

			]
		);

		// title
		$this->add_control(
			'title_control',
			[
				'label' 	=> esc_html__( 'Title', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-static-infobox-title'	=> 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'title_typography',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
				'selector'	=> '{{WRAPPER}} .dtr-static-infobox-title',

			]
		);
		$this->add_control(
			'subtitle_control',
			[
				'label' 	=> esc_html__( 'Sub Title', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-static-infobox-subtitle'	=> 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'subtitle_typography',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
				'selector'	=> '{{WRAPPER}} .dtr-static-infobox-subtitle',

			]
		);
		
		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		
		// link
		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_render_attribute( 'button', 'href', $settings['link']['url'] );
			$this->add_render_attribute( 'button', 'class', 'dtr-wrapping-link' );
			if ( $settings['link']['is_external'] ) {
				$this->add_render_attribute( 'button', 'target', '_blank' );
			}
			if ( $settings['link']['nofollow'] ) {
				$this->add_render_attribute( 'button', 'rel', 'nofollow' );
			}
		}
		$this->add_render_attribute( 'button', 'role', 'button' );
		
		?>
		<div class="dtr-static-infobox">
        	<?php if ( ! empty( $settings['link']['url'] ) ) { ?>
            <a <?php echo $this->get_render_attribute_string( 'button' ); ?> aria-label="<?php echo esc_html( $settings['infobox_title'] ) ?>"></a>
           <?php } ?>
            <div class="dtr-static-infobox-overlay"></div>
            <?php if ( ! empty( $settings['image']['url'] ) ) { ?>
            <?php $this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
            $this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
            $this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
            $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' ); ?>
            <?php echo $image_html ?>
            <?php } ?>
            <div class="dtr-static-infobox-content">
                <?php if ( ! empty( $settings['infobox_title'] ) ) { ?>
                    <h4 class="dtr-static-infobox-title"><?php echo esc_html( $settings['infobox_title'] ) ?></h4>
                <?php } ?>
                <?php if ( ! empty( $settings['infobox_sub_title'] ) ) { ?>
                    <p class="dtr-static-infobox-subtitle"><?php echo esc_html( $settings['infobox_sub_title'] ) ?></p>
                <?php } ?>
            </div>
        </div>
		<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
		<div class="dtr-static-infobox">
        	<a class="dtr-wrapping-link" href="#"></a>
            <div class="dtr-static-infobox-overlay"></div>
            <#	if ( settings.image.url ) { #>
                <#
                var image = {
                id: settings.image.id,
                url: settings.image.url,
                size: settings.thumbnail_size,
                dimension: settings.thumbnail_custom_dimension,
                model: view.getEditModel()
                };
                var image_url = elementor.imagesManager.getImageUrl( image );  #>
                <img src="{{ image_url }}"/>
            <# } #>
            <div class="dtr-static-infobox-content">
                <# if ( settings.infobox_title ) { #>
                    <h4 class="dtr-static-infobox-title">{{{settings.infobox_title }}}</h4>
                <# } #>
                  <# if ( settings.infobox_sub_title ) { #>
                    <p class="dtr-static-infobox-subtitle">{{{settings.infobox_sub_title }}}</p>
                <# } #>
             </div>
        </div>
		<?php
	}
}