<?php
namespace AmberyAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\REPEATER;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Tabs Widget
 */
class Ambery_Tabs extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-styled-tabs';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Tabs', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}
	
	public function get_keywords() {
		return [ 'tabs', 'accordion', 'toggle' ];
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	
	/**
	 * Register the scripts widget depends on.
	 */
	public function __construct( $data = [], $args = null ) {
		parent::__construct( $data, $args );
		wp_register_script( 'dtr-widgets', AMBERY_ELEMENTOR_ADDONS_URL . 'assets/js/dtr-widgets.js', [ 'elementor-frontend' ], '1.0.0', true );
		wp_register_script( 'bootstrap.min', AMBERY_ELEMENTOR_ADDONS_URL . 'assets/js/bootstrap.min.js', [ 'elementor-frontend' ], '1.0.0', true );
    }
   
	/**
	 * Retrieve the list of scripts the widget depends on.
	 * Used to set scripts dependencies required to run the widget.
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
        return [
		    'bootstrap.min',
			'dtr-widgets'
        ];
    }
	
	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_timeline_content',
			[
				'label'	=> esc_html__( 'Tabs', 'ambery' ),
			]
		);

		$repeater = new Repeater();
		
		// title
		$repeater->add_control(
			'tab_title',
			[
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> __( 'Nav Title', 'ambery' ),
				'label_block' 	=> true,
			]
		);

		// content
		$repeater->add_control(
			'tab_content',
			[
				'label' 		=> __( 'Content', 'ambery' ),
				'default' 		=> __( 'Tab Content', 'ambery' ),
				'placeholder'	=> __( 'Tab Content', 'ambery' ),
				'type' 			=> Controls_Manager::WYSIWYG,
				'show_label' 	=> true,
			]
		);
		
		// items
		$this->add_control(
			'tabs',
			[
				'label' 	=> __( 'Tabs Items', 'ambery' ),
				'type' 		=> Controls_Manager::REPEATER,
				'fields' 	=> $repeater->get_controls(),
				'default' 	=> [
					[
						'tab_title' 			=> __( 'Tab #1', 'ambery' ),
						'tab_content'	=> __( 'Tab #1 Content', 'ambery' ),
					],
					[
						'tab_title' 			=> __( 'Tab #2', 'ambery' ),
						'tab_content'	=> __( 'Tab #2 Content', 'ambery' ),
					],
					[
						'tab_title' 			=> __( 'Tab #3', 'ambery' ),
						'tab_content'	=> __( 'Tab #3 Content', 'ambery' ),
					],
				],
				'title_field'	=> '{{{ tab_title }}}',
			]
		);

		$this->add_control(
			'view',
			[
				'label' 	=> __( 'View', 'ambery' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
			
		$this->end_controls_section();
		// content control ends

		// section_tab_title_style starts
		$this->start_controls_section(
			'section_tab_title_style',
			[
				'label'	=> esc_html__( 'Tab Title', 'ambery' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		// tab_title
		$this->add_control(
			'tab_nav_style_control',
			[
				'label'	=> esc_html__( 'Tab Nav', 'ambery' ),
				'type' 	=> Controls_Manager::HEADING,
			]
		);
		
		$this->add_control(
			'tab_nav_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-tabs .nav-link' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'tab_nav_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector'	=> '{{WRAPPER}} .dtr-tabs .nav-link',
            ]
        );
		
		$this->add_control(
			'tab_active_nav_color',
			[
				'label' 	=> esc_html__( 'Hover / Active Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'separator' => 'before',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-tabs .nav-link:hover, {{WRAPPER}} .dtr-tabs .nav-link.active' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'tab_nav_border_color',
			[
				'label' 	=> esc_html__( 'Border Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-tabs .dtr-tabs-nav' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'tab_active_border_color',
			[
				'label' 	=> esc_html__( 'Active Tab Border Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-tabs .nav-link.active, {{WRAPPER}} .dtr-tabs .nav-link.active:hover' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		// tab_content
		$this->add_control(
			'tab_content_style_control',
			[
				'label'	=> esc_html__( 'Tab Content', 'ambery' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'tab_content_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-tabs .tab-content' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'tab_content_link_color',
			[
				'label' 	=> esc_html__( 'Link in Content : Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-tabs .tab-content a' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'tab_content_link_hover',
			[
				'label' 	=> esc_html__( 'Link in Content : Hover Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-tabs .tab-content a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'tab_content_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector'	=> '{{WRAPPER}} .dtr-tabs .tab-content',
            ]
        );
		
		$this->end_controls_section();
		// section_tab_column1_style ends				
				
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		$tabs = $this->get_settings_for_display( 'tabs' );
		$id_int = substr( $this->get_id_int(), 0, 3 );
		?>
        <div class="dtr-tabs">
            <div class="dtr-tabs-nav nav nav-tabs" role="tablist">
                <?php                   
                foreach ( $tabs as $index => $item ) :
                $tab_count = $index + 1;
                $tab_title_setting_key = $this->get_repeater_setting_key( 'tab_title', 'tabs', $index );
                $this->add_render_attribute( $tab_title_setting_key, [
                    'id' 		=> 'dtr-tab-title-' . $id_int . $tab_count,
                    'class' 	=> [ 'nav-link', 'clearfix' ],
                    'role' 		=> 'tab',
					'aria-controls' => 'dtr-tab-content-' . $id_int . $tab_count,
                ] );
                ?>
                <a data-bs-toggle="tab" href="#<?php echo esc_html( 'dtr-tab-content-' . $id_int . $tab_count ) ?>" <?php $this->print_render_attribute_string( $tab_title_setting_key ); ?>><?php if ( $item['tab_title'] != '' ) { echo esc_html( $item['tab_title'] ); } ?></a>
                <?php endforeach; ?>
            </div>
            <div class="tab-content">
                <?php
                foreach ( $tabs as $index => $item ) :
                $tab_count = $index + 1; 
                $tab_content_setting_key = $this->get_repeater_setting_key( 'tab_content', 'tabs', $index );
				$this->add_render_attribute( $tab_content_setting_key, [
					'id' => 'dtr-tab-content-' . $id_int . $tab_count,
					'class' => [ 'tab-pane' ],
					'role' => 'tabpanel',
					'aria-labelledby' => 'dtr-tab-title-' . $id_int . $tab_count,
				] );
				$this->add_inline_editing_attributes( $tab_content_setting_key, 'advanced' );
                ?>
                <div <?php $this->print_render_attribute_string( $tab_content_setting_key ); ?>>
                   <?php $this->print_text_editor( $item['tab_content'] ); ?>
                </div>
                <?php endforeach; ?>
            </div>
		</div>
		<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
        <div class="dtr-tabs">
         <# if ( settings.tabs ) {
			var tabindex = view.getIDInt().toString().substr( 0, 3 ); #>
            <div class="dtr-tabs-nav nav nav-tabs" role="tablist">
                <#
                _.each( settings.tabs, function( item, index ) {
                var tabCount = index + 1;
                #>
               <a href="#dtr-tab-content-{{ tabindex + tabCount }}" id="dtr-tab-title-{{ tabindex + tabCount }}" class="nav-link"  role="tab" data-bs-toggle="tab">{{{ item.tab_title }}}</a>
                <# } ); #>
            </div>
            <div class="tab-content">
            <#
            _.each( settings.tabs, function( item, index ) {
            var tabCount = index + 1,
            tabContentKey = view.getRepeaterSettingKey( 'tab_content', 'tabs',index );
            view.addRenderAttribute( tabContentKey, {
            'id': 'dtr-tab-content-' + tabindex + tabCount,
            'class': [ 'tab-pane' ],
            'role' : 'tabpanel',
            } );
            view.addInlineEditingAttributes( tabContentKey, 'advanced' ); #>
            <div {{{ view.getRenderAttributeString( tabContentKey ) }}}>
                <# if ( item.tab_content ) { #>
                {{{ item.tab_content }}}
                <# } #>
            </div>
            <# } ); #>
            </div>
			<# } #>
		</div>
		<?php
	}
}