<?php
namespace AmberyAddons\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
use Elementor\Icons_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * Team Widget
 */
class Ambery_Team extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-team';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Team', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		  return array('dtr-element');

	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// image control starts
		$this->start_controls_section(
			'section_team_image',
			[
				'label'	=> esc_html__( 'Team', 'ambery' ),
			]
		);

		// image
		$this->add_control(
			'team_image_control',
			[
				'label' => esc_html__( 'Image', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);		
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'ambery' ),
				'type' 		=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> Utils::get_placeholder_image_src(),
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
			]
		);
		// title
		$this->add_control(
			'team_title',
			[
				'label' 		=> esc_html__( 'Name', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Name Goes Here', 'ambery' ),
				'placeholder'	=> esc_html__( 'Name', 'ambery' ),
				'label_block' 	=> true,
				'separator' 	=> 'before',
			]
		);
		
		// sub title
		$this->add_control(
			'team_sub_title',
			[
				'label' 		=> esc_html__( 'Designation', 'ambery' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Designation', 'ambery' ),
				'placeholder'	=> esc_html__( 'Designation', 'ambery' ),
				'label_block' 	=> true,
			]
		);
	
		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'ambery' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		
		// social
		$this->start_controls_section(
			'section_social_icon',
			[
				'label'	=> esc_html__( 'Social Icons', 'elementor' ),
			]
		);
		
		$this->add_control(
			'team_social',
			[
				'label' 	=> esc_html__( 'Social', 'ambery' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> 'show',
				'options'	=> [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'	=> esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
		
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'social_icon',
			[
				'label' 			=> __( 'Icon', 'elementor' ),
				'type' 				=> Controls_Manager::ICONS,
				'fa4compatibility'	=> 'social',
				'label_block'		=> true,
				'default'			=> [
					'value'		=> 'fab fa-wordpress',
					'library'	=> 'fa-brands',
				],
				'recommended'		=> [
					'fa-brands'	=> [
						'android',
						'apple',
						'behance',
						'bitbucket',
						'codepen',
						'delicious',
						'deviantart',
						'digg',
						'dribbble',
						'elementor',
						'facebook',
						'flickr',
						'foursquare',
						'free-code-camp',
						'github',
						'gitlab',
						'globe',
						'google-plus',
						'houzz',
						'instagram',
						'jsfiddle',
						'linkedin',
						'medium',
						'meetup',
						'mixcloud',
						'odnoklassniki',
						'pinterest',
						'product-hunt',
						'reddit',
						'shopping-cart',
						'skype',
						'slideshare',
						'snapchat',
						'soundcloud',
						'spotify',
						'stack-overflow',
						'steam',
						'stumbleupon',
						'telegram',
						'thumb-tack',
						'tripadvisor',
						'tumblr',
						'twitch',
						'twitter',
						'viber',
						'vimeo',
						'vk',
						'weibo',
						'weixin',
						'whatsapp',
						'wordpress',
						'xing',
						'yelp',
						'youtube',
						'500px',
					],
					'fa-solid'	=> [
						'envelope',
						'link',
						'rss',
					],
				],
			]
		);

		$repeater->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'elementor' ),
				'type' 			=> Controls_Manager::URL,
				'label_block'	=> true,
				'default'		=> [
					'is_external'	=> 'true',
				],
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'elementor' ),
			]
		);

		$this->add_control(
			'social_icon_list',
			[
				'label' 		=> __( 'Social Icons', 'elementor' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields'		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'social_icon'	=> [
							'value' 	=> 'fab fa-twitter',
							'library' 	=> 'fa-brands',
						],
					],
				],
				'title_field'	=> '<# var migrated = "undefined" !== typeof __fa4_migrated, social = ( "undefined" === typeof social ) ? false : social; #>{{{ elementor.helpers.getSocialNetworkNameFromIcon( social_icon, social, true, migrated, true ) }}}',
			]
		);
		
		$this->end_controls_section();
		// social ends
		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label'	=> esc_html__( 'Styles', 'ambery' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'team_content_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'separator'	=> 'before',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-team-content '	=> 'background-color: {{VALUE}};',
				],
			]
		);

		// title
		$this->add_control(
			'team_title_control',
			[
				'label' 	=> esc_html__( 'Title', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		$this->add_control(
			'team_title_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-team-title'	=> 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'team_title_typography',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
				'selector'	=> '{{WRAPPER}} .dtr-team-title',

			]
		);
		$this->add_control(
			'team_subtitle_control',
			[
				'label' 	=> esc_html__( 'Designation', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		$this->add_control(
			'team_subtitle_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-team-subtitle'	=> 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'team_subtitle_typography',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
				'selector'	=> '{{WRAPPER}} .dtr-team-subtitle',

			]
		);

		$this->add_control(
			'team_social_control',
			[
				'label' 	=> esc_html__( 'Social Icons', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'team_social_color',
			[
				'label' 	=> esc_html__( 'Icon Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-team-social a'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'team_social_hover_color',
			[
				'label' 	=> esc_html__( 'Hover : Icon Color', 'ambery' ),
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-team-social a:hover'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		
		// icons
		$fallback_defaults = [
			'fa fa-twitter',
		];
		$migration_allowed = Icons_Manager::is_migration_allowed();
	  ?>
		<div class="dtr-team">
			<?php if ( ! empty( $settings['image']['url'] ) ) { ?>
            <div class="dtr-team-img">
				<?php
                $this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
                $this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
                $this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
                $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' ); ?>
                <?php echo $image_html ?>
            </div>
            <!-- team image wrapper -->
            <?php } ?>
        	<div class="dtr-team-content"> 
                <div class="dtr-team-inner-content">
                <?php if ( ! empty( $settings['team_title'] ) ) { ?>
                    <h4 class="dtr-team-title"><?php echo esc_html( $settings['team_title'] ) ?></h4>
                <?php } ?>
                <?php if ( ! empty( $settings['team_sub_title'] ) ) { ?>
                    <p class="dtr-team-subtitle"><?php echo esc_html( $settings['team_sub_title'] ) ?></p>
                <?php } ?>
                </div>
            <?php if ( $settings['team_social'] == 'show' ) { ?>
                <div class="dtr-team-social">
                    <?php
                    foreach ( $settings['social_icon_list'] as $index => $item ) {
                    $migrated = isset( $item['__fa4_migrated']['social_icon'] );
                    $is_new = empty( $item['social'] ) && $migration_allowed;
                    $social = '';
    
                    // add old default
                    if ( empty( $item['social'] ) && ! $migration_allowed ) {
                        $item['social'] = isset( $fallback_defaults[ $index ] ) ? $fallback_defaults[ $index ] : 'fa fa-wordpress';
                    }
    
                    if ( ! empty( $item['social'] ) ) {
                        $social = str_replace( 'fa fa-', '', $item['social'] );
                    }
    
                    if ( ( $is_new || $migrated ) && 'svg' !== $item['social_icon']['library'] ) {
                        $social = explode( ' ', $item['social_icon']['value'], 2 );
                        if ( empty( $social[1] ) ) {
                            $social = '';
                        } else {
                            $social = str_replace( 'fa-', '', $social[1] );
                        }
                    }
                    if ( 'svg' === $item['social_icon']['library'] ) {
                        $social = '';
                    }
    
                    $link_key = 'link_' . $index;
    
                    $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );
    
                    $this->add_render_attribute( $link_key, 'class', [
                        'dtr-team-social-icon',
                        'elementor-repeater-item-' . $item['_id'],
                    ] );
    
                    if ( $item['link']['is_external'] ) {
                        $this->add_render_attribute( $link_key, 'target', '_blank' );
                    }
    
                    if ( $item['link']['nofollow'] ) {
                        $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                    }
    
                    ?>
                    <a <?php echo $this->get_render_attribute_string( $link_key ); ?> aria-label="<?php echo ucwords( $social ); ?>">
                        <span class="elementor-screen-only"><?php echo ucwords( $social ); ?></span>
                        <?php
                        if ( $is_new || $migrated ) {
                            Icons_Manager::render_icon( $item['social_icon'] );
                        } else { ?>
                            <i class="<?php echo esc_attr( $item['social'] ); ?>"></i>
                        <?php } ?>
                    </a>
                    <?php } ?>
                </div>
            <?php } ?>
            <!-- team social -->  
        	</div>
        </div>
		<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
		<# var iconsHTML = {}; #>
		<div class="dtr-team">
                <#	if ( settings.image.url ) { #>
                    <div class="dtr-team-img">
                        <#
                        var image = {
                        id: settings.image.id,
                        url: settings.image.url,
                        size: settings.thumbnail_size,
                        dimension: settings.thumbnail_custom_dimension,
                        model: view.getEditModel()
                        };
                        var image_url = elementor.imagesManager.getImageUrl( image );  #>
                        <img src="{{ image_url }}"/>
                    </div>	
                <# } #>
                <div class="dtr-team-content"> 
                
                <div class="dtr-team-inner-content">
                    <# if ( settings.team_title ) { #>
                        <h4 class="dtr-team-title">{{{settings.team_title }}}</h4>
                    <# } #>
                      <# if ( settings.team_sub_title ) { #>
                        <p class="dtr-team-subtitle">{{{settings.team_sub_title }}}</p>
                    <# } #>
                 </div>
                  
                 	<# if ( settings.team_social == 'show' ) { #>
                    <div class="dtr-team-social">
                        <# _.each( settings.social_icon_list, function( item, index ) {
                            var link = item.link ? item.link.url : '',
                                migrated = elementor.helpers.isIconMigrated( item, 'social_icon' );
                                social = elementor.helpers.getSocialNetworkNameFromIcon( item.social_icon, item.social, false, migrated );
                        #>
                            <a class="dtr-team-social-icon elementor-repeater-item-{{item._id}}" href="{{ link }}">
                            <span class="elementor-screen-only">{{{ social }}}</span>
                            <# 	
                                iconsHTML[ index ] = elementor.helpers.renderIcon( view, item.social_icon, {}, 'i', 'object' );
                                if ( ( ! item.social || migrated ) && iconsHTML[ index ] && iconsHTML[ index ].rendered ) { #>
                                    {{{ iconsHTML[ index ].value }}}
                                <# } else { #>
                                    <i class="{{ item.social }}"></i>
                                <# }
                            #>
                        </a>
                        <# } ); #>
                    </div>
                    <# } #>
            </div>
        </div>
		<?php
	}
}