<?php
namespace AmberyAddons\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Testimonial Carousel Widget
 */
class Ambery_Testimonial_Thumbs_Carousel extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-testimonial-thumbs-carousel';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Testimonial Carousel With Thumbs', 'ambery' );
	}
 
	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	
	/**
	 * Register the scripts widget depends on.
	 */
	public function __construct( $data = [], $args = null ) {
		parent::__construct( $data, $args );
	  	wp_register_script( 'swiper', AMBERY_ELEMENTOR_ADDONS_URL . 'assets/js/swiper-bundle.min.js', [ 'elementor-frontend' ], '8.4.5', true );
		wp_register_script( 'dtr-widgets', AMBERY_ELEMENTOR_ADDONS_URL . 'assets/js/dtr-widgets.js', [ 'elementor-frontend' ], '1.0.0', true );
		wp_register_style( 'swiper', AMBERY_ELEMENTOR_ADDONS_URL . 'assets/css/swiper.min.css' );
    }
	
	/**
	 * Retrieve the list of scripts the widget depends on.
	 * Used to set scripts dependencies required to run the widget.
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
        return [
			'swiper',
			'dtr-widgets'
        ];
    }
	
	/**
	 * Retrieve the list of styles the widget depends on.
	 * Used to set styles dependencies required to run the widget.
	 * @return array Widget styles dependencies.
	 */
	public function get_style_depends() {
        return [
			'swiper'
        ];
    }
	
	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// content control starts
		$this->start_controls_section(
			'section_testimonial_content',
			[
				'label' => esc_html__( 'Testimonial Carousel', 'ambery' ),
			]
		);

		$this->add_control(
			'post_limit',
			[
				'label' 		=> esc_html__( 'Number of posts to scroll', 'ambery' ),
				'description'	=> esc_html__( '-1 to show all posts', 'ambery' ),
				'type' 			=> Controls_Manager::NUMBER,
				'default'		=> '-1',
				'min' 			=> -1,
				'step' 			=> 1,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'post_orderby',
			[
				'label' 		=> esc_html__( 'Sort Testimonials By', 'ambery' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> 'date',
				'label_block'	=> true,
				'options'	=> [
					'date' 	=> esc_html__( 'Date', 'ambery' ),
					'rand' 	=> esc_html__( 'Random', 'ambery' ),
					'title'	=> esc_html__( 'Title', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'post_order',
			[
				'label' 		=> esc_html__( 'Arrange Sorted Testimonials', 'ambery' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> 'DESC',
				'label_block'	=> true,
				'options'	=> [
					'DESC'	=> esc_html__( 'Descending', 'ambery' ),
					'ASC'  	=> esc_html__( 'Ascending', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'ambery' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label'	=> esc_html__( 'Styles', 'ambery' ),
				'tab'	=> Controls_Manager::TAB_STYLE,
			]
		);
		
		// testimonial_tagline_typo_styles
		$this->add_control(
			'testimonial_tagline_typo_styles',
			[
				'label'	=> esc_html__( 'Tagline', 'ambery' ),
				'type'	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
			
		$this->add_control(
			'testimonial_tagline_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-testimonial-tagline' => 'color: {{VALUE}};',
				],
			]
		);
			
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'testimonial_tagline_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-testimonial-tagline',
            ]
        );
		
		// testimonial_content_typo_styles
		$this->add_control(
			'testimonial_content_typo_styles',
			[
				'label'	=> esc_html__( 'Content', 'ambery' ),
				'type'	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
			
		$this->add_control(
			'testimonial_text_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-testimonial-content' => 'color: {{VALUE}};',
				],
			]
		);
			
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'testimonial_text_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-testimonial-content',
            ]
        );
		
		// testimonial_client_typo_styles
		$this->add_control(
			'testimonial_client_typo_styles',
			[
				'label' 	=> esc_html__( 'Client Name', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'testimonial_client_name_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-client-name' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'testimonial_client_name_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-client-name',
            ]
        );
		
		// testimonial_designation_typo_styles
		$this->add_control(
			'testimonial_designation_typo_styles',
			[
				'label' 	=> esc_html__( 'Designation', 'ambery' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'testimonial_client_job_color',
			[
				'label' 	=> esc_html__( 'Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-client-job' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'testimonial_client_job_typo',
				'label' 	=> esc_html__( 'Typography', 'ambery' ),
                'selector' 	=> '{{WRAPPER}} .dtr-client-job',
            ]
        );

		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	 protected function render() {
		$settings = $this->get_settings();
		
		echo do_shortcode('[dtr_testimonial_thumbs_carousel limit="' . esc_html( $settings['post_limit'] ) . '" orderby="' . $settings['post_orderby'] . '" order="' . $settings['post_order'] . '"]');
	}
}