<?php
namespace AmberyAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Control_Media;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Ambery_Video_Lightbox extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-video-lightbox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Video Lightbox', 'ambery' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}
	
	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	
	
	/**
	 * Register the scripts widget depends on.
	 */
	public function __construct( $data = [], $args = null ) {
		parent::__construct( $data, $args );
		wp_register_script( 'venobox', AMBERY_ELEMENTOR_ADDONS_URL . 'assets/js/venobox.min.js', [ 'elementor-frontend' ], '2.0.4', true );
		wp_register_script( 'dtr-widgets', AMBERY_ELEMENTOR_ADDONS_URL . 'assets/js/dtr-widgets.js', [ 'elementor-frontend' ], '1.0.0', true );
		wp_register_style( 'venobox', AMBERY_ELEMENTOR_ADDONS_URL . 'assets/css/venobox.css' );
    } 
	
	/**
	 * Retrieve the list of scripts the widget depends on.
	 * Used to set scripts dependencies required to run the widget.
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
        return [
			'venobox',
			'dtr-widgets'
        ];
    }
	
	/**
	 * Retrieve the list of styles the widget depends on.
	 * Used to set styles dependencies required to run the widget.
	 * @return array Widget styles dependencies.
	 */
	public function get_style_depends() {
        return [
			'venobox'
        ];
    }

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_video_btn',
			[
				'label' => __( 'Video Button', 'ambery' ),
			]
		);
		
		$this->add_control(
			'bg_img',
			[
				'label' => esc_html__( 'Background Image', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'hide',
				'label_block' => true,
				'options' => [
					'show'	=> esc_html__( 'Show', 'ambery' ),
					'hide'	=> esc_html__( 'Hide', 'ambery' ),
				],
			]
		);
		
		// image
		$this->add_control(
			'image_control',
			[
				'label' => esc_html__( 'Image', 'ambery' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'bg_img'	=> [ 'show' ],
				],
			]
		);	
			
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'ambery' ),
				'type' 		=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'bg_img'	=> [ 'show' ],
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
				'condition' => [
					'bg_img'	=> [ 'show' ],
				],
			]
		);
		
		$this->add_control(
			'video_autoplay',
			[
				'label' => esc_html__( 'Autoplay', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'yes',
				'separator' 	=> 'before',
				'label_block' => true,
				'options' => [
					'yes'	=> esc_html__( 'Yes', 'ambery' ),
					'no'	=> esc_html__( 'No', 'ambery' ),
				],
			]
		);
		
		// link
		$this->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'ambery' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> '#',
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		);

		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'ambery' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Styles', 'ambery' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'video_text_color',
			[
				'label' => esc_html__( 'Circle Text Color Type', 'ambery' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-white-text',
				'label_block' => true,
				'options' => [
					'dtr-white-text'	=> esc_html__( 'White', 'ambery' ),
					'dtr-dark-text'		=> esc_html__( 'Dark', 'ambery' ),
				],
			]
		);
		
		$this->add_control(
			'btn_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'separator' => 'before',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-video-button' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'btn_icon_color',
			[
				'label' 	=> esc_html__( 'Icon Color', 'ambery' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-video-button::after' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

		/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		$autoplay = '';
		if ($settings['video_autoplay'] == 'yes' ) {
			$autoplay = 'data-autoplay="true"';
		} else {
			$autoplay = ''; 
		}
		?>
        <div class="dtr-video-box <?php echo esc_attr( $settings['video_text_color'] ) ?>">
        <div class="dtr-overlay"></div>           
        <?php if ( ! empty( $settings['image']['url'] ) && $settings['bg_img'] == 'show' ) {
			$this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
			$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
			$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
			$image_html = Group_Control_Image_Size::get_attachment_image_html( $settings ); 
			echo $image_html;
        } ?>
        	<a class="dtr-video-popup dtr-video-button" data-vbtype="video" data-maxwidth="85%" <?php echo esc_attr( $autoplay ) ?>  href="<?php echo esc_url( $settings['link'] ) ?>" aria-label="Video Button"></a> </div>
        <?php	}
	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
	?>
   	 <div class="dtr-video-box {{{settings.video_text_color }}}">
        <div class="dtr-overlay"></div>
         <#	if ( settings.image.url && settings.bg_img == 'show' ) { #>
            <#
            var image = {
            id: settings.image.id,
            url: settings.image.url,
            size: settings.thumbnail_size,
            dimension: settings.thumbnail_custom_dimension,
            model: view.getEditModel()
            };
            var image_url = elementor.imagesManager.getImageUrl( image );  #>
            <img src="{{ image_url }}"/>
        <# } #>
    	<a class="dtr-video-popup dtr-video-button" data-vbtype="video" data-maxwidth="85%" href="{{ settings.link }}" aria-hidden="true"></a>
   </div>
<?php
	}
}